Class: Google::Apis::CloudbuildV1::Artifacts

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

Artifacts produced by a build that should be uploaded upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Artifacts

Returns a new instance of Artifacts.



245
246
247
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 245

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#generic_artifactsArray<Google::Apis::CloudbuildV1::GenericArtifact>

Optional. A list of generic artifacts to be uploaded to Artifact Registry upon successful completion of all build steps. If any artifacts fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property genericArtifacts



186
187
188
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 186

def generic_artifacts
  @generic_artifacts
end

#go_modulesArray<Google::Apis::CloudbuildV1::GoModule>

Optional. A list of Go modules to be uploaded to Artifact Registry upon successful completion of all build steps. If any objects fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property goModules



193
194
195
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 193

def go_modules
  @go_modules
end

#imagesArray<String>

A list of images to be pushed upon the successful completion of all build steps. The images will be pushed using the builder service account's credentials. The digests of the pushed images will be stored in the Build resource's results field. If any of the images fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property images

Returns:

  • (Array<String>)


202
203
204
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 202

def images
  @images
end

#maven_artifactsArray<Google::Apis::CloudbuildV1::MavenArtifact>

A list of Maven artifacts to be uploaded to Artifact Registry upon successful completion of all build steps. Artifacts in the workspace matching specified paths globs will be uploaded to the specified Artifact Registry repository using the builder service account's credentials. If any artifacts fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property mavenArtifacts



211
212
213
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 211

def maven_artifacts
  @maven_artifacts
end

#npm_packagesArray<Google::Apis::CloudbuildV1::NpmPackage>

A list of npm packages to be uploaded to Artifact Registry upon successful completion of all build steps. Npm packages in the specified paths will be uploaded to the specified Artifact Registry repository using the builder service account's credentials. If any packages fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property npmPackages



220
221
222
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 220

def npm_packages
  @npm_packages
end

#objectsGoogle::Apis::CloudbuildV1::ArtifactObjects

Files in the workspace to upload to Cloud Storage upon successful completion of all build steps. Corresponds to the JSON property objects



226
227
228
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 226

def objects
  @objects
end

#ociArray<Google::Apis::CloudbuildV1::Oci>

Optional. A list of OCI images to be uploaded to Artifact Registry upon successful completion of all build steps. OCI images in the specified paths will be uploaded to the specified Artifact Registry repository using the builder service account's credentials. If any images fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property oci



235
236
237
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 235

def oci
  @oci
end

#python_packagesArray<Google::Apis::CloudbuildV1::PythonPackage>

A list of Python packages to be uploaded to Artifact Registry upon successful completion of all build steps. The build service account credentials will be used to perform the upload. If any objects fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property pythonPackages



243
244
245
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 243

def python_packages
  @python_packages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



250
251
252
253
254
255
256
257
258
259
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 250

def update!(**args)
  @generic_artifacts = args[:generic_artifacts] if args.key?(:generic_artifacts)
  @go_modules = args[:go_modules] if args.key?(:go_modules)
  @images = args[:images] if args.key?(:images)
  @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts)
  @npm_packages = args[:npm_packages] if args.key?(:npm_packages)
  @objects = args[:objects] if args.key?(:objects)
  @oci = args[:oci] if args.key?(:oci)
  @python_packages = args[:python_packages] if args.key?(:python_packages)
end