Class: Google::Apis::CloudbuildV1::BuiltImage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

An image built by the pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BuiltImage

Returns a new instance of BuiltImage.



1610
1611
1612
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 1610

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


1586
1587
1588
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 1586

def artifact_registry_package
  @artifact_registry_package
end

#digestString

Docker Registry 2.0 digest. Corresponds to the JSON property digest

Returns:

  • (String)


1591
1592
1593
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 1591

def digest
  @digest
end

#nameString

Name used to push the container image to Google Container Registry, as presented to docker push. Corresponds to the JSON property name

Returns:

  • (String)


1597
1598
1599
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 1597

def name
  @name
end

#oci_media_typeString

Output only. The OCI media type of the artifact. Non-OCI images, such as Docker images, will have an unspecified value. Corresponds to the JSON property ociMediaType

Returns:

  • (String)


1603
1604
1605
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 1603

def oci_media_type
  @oci_media_type
end

#push_timingGoogle::Apis::CloudbuildV1::TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



1608
1609
1610
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 1608

def push_timing
  @push_timing
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1615
1616
1617
1618
1619
1620
1621
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 1615

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @digest = args[:digest] if args.key?(:digest)
  @name = args[:name] if args.key?(:name)
  @oci_media_type = args[:oci_media_type] if args.key?(:oci_media_type)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
end