Class: Google::Apis::CloudbuildV1::Dependency

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

A dependency that the Cloud Build worker will fetch before executing user steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Dependency

Returns a new instance of Dependency.



2064
2065
2066
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2064

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emptyBoolean Also known as: empty?

If set to true disable all dependency fetching (ignoring the default source as well). Corresponds to the JSON property empty

Returns:

  • (Boolean)


2051
2052
2053
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2051

def empty
  @empty
end

#generic_artifactGoogle::Apis::CloudbuildV1::GenericArtifactDependency

Represents a generic artifact as a build dependency. Corresponds to the JSON property genericArtifact



2057
2058
2059
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2057

def generic_artifact
  @generic_artifact
end

#git_sourceGoogle::Apis::CloudbuildV1::GitSourceDependency

Represents a git repository as a build dependency. Corresponds to the JSON property gitSource



2062
2063
2064
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2062

def git_source
  @git_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2069
2070
2071
2072
2073
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2069

def update!(**args)
  @empty = args[:empty] if args.key?(:empty)
  @generic_artifact = args[:generic_artifact] if args.key?(:generic_artifact)
  @git_source = args[:git_source] if args.key?(:git_source)
end