Class: Google::Apis::CloudbuildV1::DeveloperConnectConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

This config defines the location of a source through Developer Connect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeveloperConnectConfig

Returns a new instance of DeveloperConnectConfig.



2097
2098
2099
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2097

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dirString

Required. Directory, relative to the source root, in which to run the build. Corresponds to the JSON property dir

Returns:

  • (String)


2083
2084
2085
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2083

def dir
  @dir
end

Required. The Developer Connect Git repository link, formatted as projects/*/ locations/*/connections/*/gitRepositoryLink/*. Corresponds to the JSON property gitRepositoryLink

Returns:

  • (String)


2089
2090
2091
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2089

def git_repository_link
  @git_repository_link
end

#revisionString

Required. The revision to fetch from the Git repository such as a branch, a tag, a commit SHA, or any Git ref. Corresponds to the JSON property revision

Returns:

  • (String)


2095
2096
2097
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2095

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2102
2103
2104
2105
2106
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2102

def update!(**args)
  @dir = args[:dir] if args.key?(:dir)
  @git_repository_link = args[:git_repository_link] if args.key?(:git_repository_link)
  @revision = args[:revision] if args.key?(:revision)
end