Class: Google::Apis::CloudbuildV1::DeveloperConnectEventConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

The configuration of a trigger that creates a build whenever an event from the DeveloperConnect API is received.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeveloperConnectEventConfig

Returns a new instance of DeveloperConnectEventConfig.



2135
2136
2137
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2135

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Required. The Developer Connect Git repository link, formatted as projects/*/ locations/*/connections/*/gitRepositoryLink/*. Corresponds to the JSON property gitRepositoryLink

Returns:

  • (String)


2118
2119
2120
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2118

def git_repository_link
  @git_repository_link
end

Output only. The type of DeveloperConnect GitRepositoryLink. Corresponds to the JSON property gitRepositoryLinkType

Returns:

  • (String)


2123
2124
2125
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2123

def git_repository_link_type
  @git_repository_link_type
end

#pull_requestGoogle::Apis::CloudbuildV1::PullRequestFilter

PullRequestFilter contains filter properties for matching GitHub Pull Requests. Corresponds to the JSON property pullRequest



2128
2129
2130
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2128

def pull_request
  @pull_request
end

#pushGoogle::Apis::CloudbuildV1::PushFilter

Push contains filter properties for matching GitHub git pushes. Corresponds to the JSON property push



2133
2134
2135
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2133

def push
  @push
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2140
2141
2142
2143
2144
2145
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2140

def update!(**args)
  @git_repository_link = args[:git_repository_link] if args.key?(:git_repository_link)
  @git_repository_link_type = args[:git_repository_link_type] if args.key?(:git_repository_link_type)
  @pull_request = args[:pull_request] if args.key?(:pull_request)
  @push = args[:push] if args.key?(:push)
end