Class: Google::Apis::CloudbuildV1::FailureInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

A fatal problem encountered during the execution of the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FailureInfo

Returns a new instance of FailureInfo.



2122
2123
2124
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2122

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailString

Explains the failure issue in more detail using hard-coded text. Corresponds to the JSON property detail

Returns:

  • (String)


2115
2116
2117
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2115

def detail
  @detail
end

#typeString

The name of the failure. Corresponds to the JSON property type

Returns:

  • (String)


2120
2121
2122
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2120

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2127
2128
2129
2130
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2127

def update!(**args)
  @detail = args[:detail] if args.key?(:detail)
  @type = args[:type] if args.key?(:type)
end