Class: Google::Apis::CloudbuildV1::FileHashes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileHashes

Returns a new instance of FileHashes.



2206
2207
2208
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_hashArray<Google::Apis::CloudbuildV1::HashProp>

Collection of file hashes. Corresponds to the JSON property fileHash



2204
2205
2206
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2204

def file_hash
  @file_hash
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2211
2212
2213
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2211

def update!(**args)
  @file_hash = args[:file_hash] if args.key?(:file_hash)
end