Class: Google::Apis::CloudbuildV1::GitHubEnterpriseSecrets

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

GitHubEnterpriseSecrets represents the names of all necessary secrets in Secret Manager for a GitHub Enterprise server. Format is: projects//secrets/.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitHubEnterpriseSecrets

Returns a new instance of GitHubEnterpriseSecrets.



2482
2483
2484
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2482

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#oauth_client_id_nameString

The resource name for the OAuth client ID secret in Secret Manager. Corresponds to the JSON property oauthClientIdName

Returns:

  • (String)


2445
2446
2447
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2445

def oauth_client_id_name
  @oauth_client_id_name
end

#oauth_client_id_version_nameString

The resource name for the OAuth client ID secret version in Secret Manager. Corresponds to the JSON property oauthClientIdVersionName

Returns:

  • (String)


2450
2451
2452
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2450

def oauth_client_id_version_name
  @oauth_client_id_version_name
end

#oauth_secret_nameString

The resource name for the OAuth secret in Secret Manager. Corresponds to the JSON property oauthSecretName

Returns:

  • (String)


2455
2456
2457
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2455

def oauth_secret_name
  @oauth_secret_name
end

#oauth_secret_version_nameString

The resource name for the OAuth secret secret version in Secret Manager. Corresponds to the JSON property oauthSecretVersionName

Returns:

  • (String)


2460
2461
2462
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2460

def oauth_secret_version_name
  @oauth_secret_version_name
end

#private_key_nameString

The resource name for the private key secret. Corresponds to the JSON property privateKeyName

Returns:

  • (String)


2465
2466
2467
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2465

def private_key_name
  @private_key_name
end

#private_key_version_nameString

The resource name for the private key secret version. Corresponds to the JSON property privateKeyVersionName

Returns:

  • (String)


2470
2471
2472
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2470

def private_key_version_name
  @private_key_version_name
end

#webhook_secret_nameString

The resource name for the webhook secret in Secret Manager. Corresponds to the JSON property webhookSecretName

Returns:

  • (String)


2475
2476
2477
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2475

def webhook_secret_name
  @webhook_secret_name
end

#webhook_secret_version_nameString

The resource name for the webhook secret secret version in Secret Manager. Corresponds to the JSON property webhookSecretVersionName

Returns:

  • (String)


2480
2481
2482
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2480

def webhook_secret_version_name
  @webhook_secret_version_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2487

def update!(**args)
  @oauth_client_id_name = args[:oauth_client_id_name] if args.key?(:oauth_client_id_name)
  @oauth_client_id_version_name = args[:oauth_client_id_version_name] if args.key?(:oauth_client_id_version_name)
  @oauth_secret_name = args[:oauth_secret_name] if args.key?(:oauth_secret_name)
  @oauth_secret_version_name = args[:oauth_secret_version_name] if args.key?(:oauth_secret_version_name)
  @private_key_name = args[:private_key_name] if args.key?(:private_key_name)
  @private_key_version_name = args[:private_key_version_name] if args.key?(:private_key_version_name)
  @webhook_secret_name = args[:webhook_secret_name] if args.key?(:webhook_secret_name)
  @webhook_secret_version_name = args[:webhook_secret_version_name] if args.key?(:webhook_secret_version_name)
end