Class: Google::Apis::CloudbuildV1::GitHubEventsConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

GitHubEventsConfig describes the configuration of a trigger that creates a build whenever a GitHub event is received.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitHubEventsConfig

Returns a new instance of GitHubEventsConfig.



2419
2420
2421
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2419

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enterprise_config_resource_nameString

The resource name of the github enterprise config that should be applied to this installation. For example: "projects/$project_id/locations/$ location_id/githubEnterpriseConfigs/$config_id" Corresponds to the JSON property enterpriseConfigResourceName

Returns:

  • (String)


2390
2391
2392
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2390

def enterprise_config_resource_name
  @enterprise_config_resource_name
end

#installation_idFixnum

The installationID that emits the GitHub event. Corresponds to the JSON property installationId

Returns:

  • (Fixnum)


2395
2396
2397
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2395

def installation_id
  @installation_id
end

#nameString

Name of the repository. For example: The name for https://github.com/ googlecloudplatform/cloud-builders is "cloud-builders". Corresponds to the JSON property name

Returns:

  • (String)


2401
2402
2403
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2401

def name
  @name
end

#ownerString

Owner of the repository. For example: The owner for https://github.com/ googlecloudplatform/cloud-builders is "googlecloudplatform". Corresponds to the JSON property owner

Returns:

  • (String)


2407
2408
2409
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2407

def owner
  @owner
end

#pull_requestGoogle::Apis::CloudbuildV1::PullRequestFilter

PullRequestFilter contains filter properties for matching GitHub Pull Requests. Corresponds to the JSON property pullRequest



2412
2413
2414
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2412

def pull_request
  @pull_request
end

#pushGoogle::Apis::CloudbuildV1::PushFilter

Push contains filter properties for matching GitHub git pushes. Corresponds to the JSON property push



2417
2418
2419
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2417

def push
  @push
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2424
2425
2426
2427
2428
2429
2430
2431
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2424

def update!(**args)
  @enterprise_config_resource_name = args[:enterprise_config_resource_name] if args.key?(:enterprise_config_resource_name)
  @installation_id = args[:installation_id] if args.key?(:installation_id)
  @name = args[:name] if args.key?(:name)
  @owner = args[:owner] if args.key?(:owner)
  @pull_request = args[:pull_request] if args.key?(:pull_request)
  @push = args[:push] if args.key?(:push)
end