Class: Google::Apis::CloudbuildV1::GitLabConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

GitLabConfig represents the configuration for a GitLab integration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitLabConfig

Returns a new instance of GitLabConfig.



2587
2588
2589
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2587

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connected_repositoriesArray<Google::Apis::CloudbuildV1::GitLabRepositoryId>

Connected GitLab.com or GitLabEnterprise repositories for this config. Corresponds to the JSON property connectedRepositories



2552
2553
2554
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2552

def connected_repositories
  @connected_repositories
end

#create_timeString

Output only. Time when the config was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2557
2558
2559
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2557

def create_time
  @create_time
end

#enterprise_configGoogle::Apis::CloudbuildV1::GitLabEnterpriseConfig

GitLabEnterpriseConfig represents the configuration for a GitLabEnterprise integration. Corresponds to the JSON property enterpriseConfig



2563
2564
2565
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2563

def enterprise_config
  @enterprise_config
end

#nameString

The resource name for the config. Corresponds to the JSON property name

Returns:

  • (String)


2568
2569
2570
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2568

def name
  @name
end

#secretsGoogle::Apis::CloudbuildV1::GitLabSecrets

GitLabSecrets represents the secrets in Secret Manager for a GitLab integration. Corresponds to the JSON property secrets



2574
2575
2576
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2574

def secrets
  @secrets
end

#usernameString

Username of the GitLab.com or GitLab Enterprise account Cloud Build will use. Corresponds to the JSON property username

Returns:

  • (String)


2579
2580
2581
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2579

def username
  @username
end

#webhook_keyString

Output only. UUID included in webhook requests. The UUID is used to look up the corresponding config. Corresponds to the JSON property webhookKey

Returns:

  • (String)


2585
2586
2587
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2585

def webhook_key
  @webhook_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2592
2593
2594
2595
2596
2597
2598
2599
2600
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2592

def update!(**args)
  @connected_repositories = args[:connected_repositories] if args.key?(:connected_repositories)
  @create_time = args[:create_time] if args.key?(:create_time)
  @enterprise_config = args[:enterprise_config] if args.key?(:enterprise_config)
  @name = args[:name] if args.key?(:name)
  @secrets = args[:secrets] if args.key?(:secrets)
  @username = args[:username] if args.key?(:username)
  @webhook_key = args[:webhook_key] if args.key?(:webhook_key)
end