Class: Google::Apis::CloudbuildV1::GitLabConnectedRepository
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::GitLabConnectedRepository
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
Deprecated: CloudBuild GitLab V1 integration is deprecated. GitLabConnectedRepository represents a GitLab connected repository request response.
Instance Attribute Summary collapse
-
#parent ⇒ String
The name of the
GitLabConfigthat added connected repository. -
#repo ⇒ Google::Apis::CloudbuildV1::GitLabRepositoryId
GitLabRepositoryId identifies a specific repository hosted on GitLab.com or GitLabEnterprise Corresponds to the JSON property
repo. -
#status ⇒ Google::Apis::CloudbuildV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GitLabConnectedRepository
constructor
A new instance of GitLabConnectedRepository.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GitLabConnectedRepository
Returns a new instance of GitLabConnectedRepository.
2641 2642 2643 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2641 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parent ⇒ String
The name of the GitLabConfig that added connected repository. Format:
projects/project/locations/location/gitLabConfigs/config`
Corresponds to the JSON propertyparent`
2623 2624 2625 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2623 def parent @parent end |
#repo ⇒ Google::Apis::CloudbuildV1::GitLabRepositoryId
GitLabRepositoryId identifies a specific repository hosted on GitLab.com or
GitLabEnterprise
Corresponds to the JSON property repo
2629 2630 2631 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2629 def repo @repo end |
#status ⇒ Google::Apis::CloudbuildV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
2639 2640 2641 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2639 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2646 2647 2648 2649 2650 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2646 def update!(**args) @parent = args[:parent] if args.key?(:parent) @repo = args[:repo] if args.key?(:repo) @status = args[:status] if args.key?(:status) end |