Class: Google::Apis::CloudbuildV1::GitLabEventsConfig
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::GitLabEventsConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
GitLabEventsConfig describes the configuration of a trigger that creates a build whenever a GitLab event is received.
Instance Attribute Summary collapse
-
#gitlab_config ⇒ Google::Apis::CloudbuildV1::GitLabConfig
GitLabConfig represents the configuration for a GitLab integration.
-
#gitlab_config_resource ⇒ String
The GitLab config resource that this trigger config maps to.
-
#project_namespace ⇒ String
Namespace of the GitLab project.
-
#pull_request ⇒ Google::Apis::CloudbuildV1::PullRequestFilter
PullRequestFilter contains filter properties for matching GitHub Pull Requests.
-
#push ⇒ Google::Apis::CloudbuildV1::PushFilter
Push contains filter properties for matching GitHub git pushes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GitLabEventsConfig
constructor
A new instance of GitLabEventsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GitLabEventsConfig
Returns a new instance of GitLabEventsConfig.
2594 2595 2596 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2594 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gitlab_config ⇒ Google::Apis::CloudbuildV1::GitLabConfig
GitLabConfig represents the configuration for a GitLab integration.
Corresponds to the JSON property gitlabConfig
2572 2573 2574 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2572 def gitlab_config @gitlab_config end |
#gitlab_config_resource ⇒ String
The GitLab config resource that this trigger config maps to.
Corresponds to the JSON property gitlabConfigResource
2577 2578 2579 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2577 def gitlab_config_resource @gitlab_config_resource end |
#project_namespace ⇒ String
Namespace of the GitLab project.
Corresponds to the JSON property projectNamespace
2582 2583 2584 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2582 def project_namespace @project_namespace end |
#pull_request ⇒ Google::Apis::CloudbuildV1::PullRequestFilter
PullRequestFilter contains filter properties for matching GitHub Pull Requests.
Corresponds to the JSON property pullRequest
2587 2588 2589 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2587 def pull_request @pull_request end |
#push ⇒ Google::Apis::CloudbuildV1::PushFilter
Push contains filter properties for matching GitHub git pushes.
Corresponds to the JSON property push
2592 2593 2594 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2592 def push @push end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2599 2600 2601 2602 2603 2604 2605 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2599 def update!(**args) @gitlab_config = args[:gitlab_config] if args.key?(:gitlab_config) @gitlab_config_resource = args[:gitlab_config_resource] if args.key?(:gitlab_config_resource) @project_namespace = args[:project_namespace] if args.key?(:project_namespace) @pull_request = args[:pull_request] if args.key?(:pull_request) @push = args[:push] if args.key?(:push) end |