Class: Google::Apis::CloudbuildV1::GitLabRepository

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

Deprecated: CloudBuild GitLab V1 integration is deprecated. Proto Representing a GitLabRepository

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitLabRepository

Returns a new instance of GitLabRepository.



2765
2766
2767
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2765

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#browse_uriString

Link to the browse repo page on the GitLab instance Corresponds to the JSON property browseUri

Returns:

  • (String)


2742
2743
2744
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2742

def browse_uri
  @browse_uri
end

#descriptionString

Description of the repository Corresponds to the JSON property description

Returns:

  • (String)


2747
2748
2749
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2747

def description
  @description
end

#display_nameString

Display name of the repository Corresponds to the JSON property displayName

Returns:

  • (String)


2752
2753
2754
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2752

def display_name
  @display_name
end

#nameString

The resource name of the repository Corresponds to the JSON property name

Returns:

  • (String)


2757
2758
2759
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2757

def name
  @name
end

#repository_idGoogle::Apis::CloudbuildV1::GitLabRepositoryId

GitLabRepositoryId identifies a specific repository hosted on GitLab.com or GitLabEnterprise Corresponds to the JSON property repositoryId



2763
2764
2765
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2763

def repository_id
  @repository_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2770
2771
2772
2773
2774
2775
2776
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2770

def update!(**args)
  @browse_uri = args[:browse_uri] if args.key?(:browse_uri)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @repository_id = args[:repository_id] if args.key?(:repository_id)
end