Class: Google::Apis::CloudbuildV1::GitLabSecrets

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

Deprecated: CloudBuild GitLab V1 integration is deprecated. GitLabSecrets represents the secrets in Secret Manager for a GitLab integration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitLabSecrets

Returns a new instance of GitLabSecrets.



2835
2836
2837
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2835

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_access_token_versionString

Required. The resource name for the api access token’s secret version Corresponds to the JSON property apiAccessTokenVersion

Returns:

  • (String)


2815
2816
2817
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2815

def api_access_token_version
  @api_access_token_version
end

#api_key_versionString

Required. Immutable. API Key that will be attached to webhook requests from GitLab to Cloud Build. Corresponds to the JSON property apiKeyVersion

Returns:

  • (String)


2821
2822
2823
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2821

def api_key_version
  @api_key_version
end

#read_access_token_versionString

Required. The resource name for the read access token’s secret version Corresponds to the JSON property readAccessTokenVersion

Returns:

  • (String)


2826
2827
2828
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2826

def read_access_token_version
  @read_access_token_version
end

#webhook_secret_versionString

Required. Immutable. The resource name for the webhook secret’s secret version. Once this field has been set, it cannot be changed. If you need to change it, please create another GitLabConfig. Corresponds to the JSON property webhookSecretVersion

Returns:

  • (String)


2833
2834
2835
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2833

def webhook_secret_version
  @webhook_secret_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2840
2841
2842
2843
2844
2845
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2840

def update!(**args)
  @api_access_token_version = args[:api_access_token_version] if args.key?(:api_access_token_version)
  @api_key_version = args[:api_key_version] if args.key?(:api_key_version)
  @read_access_token_version = args[:read_access_token_version] if args.key?(:read_access_token_version)
  @webhook_secret_version = args[:webhook_secret_version] if args.key?(:webhook_secret_version)
end