Class: Google::Apis::CloudbuildV1::GitSourceDependency
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::GitSourceDependency
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
Represents a git repository as a build dependency.
Instance Attribute Summary collapse
-
#depth ⇒ Fixnum
Optional.
-
#dest_path ⇒ String
Required.
-
#recurse_submodules ⇒ Boolean
(also: #recurse_submodules?)
Optional.
-
#repository ⇒ Google::Apis::CloudbuildV1::GitSourceRepository
A repository for a git source.
-
#revision ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GitSourceDependency
constructor
A new instance of GitSourceDependency.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GitSourceDependency
Returns a new instance of GitSourceDependency.
2958 2959 2960 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2958 def initialize(**args) update!(**args) end |
Instance Attribute Details
#depth ⇒ Fixnum
Optional. How much history should be fetched for the build (default 1, -1 for
all history).
Corresponds to the JSON property depth
2935 2936 2937 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2935 def depth @depth end |
#dest_path ⇒ String
Required. Where should the files be placed on the worker.
Corresponds to the JSON property destPath
2940 2941 2942 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2940 def dest_path @dest_path end |
#recurse_submodules ⇒ Boolean Also known as: recurse_submodules?
Optional. True if submodules should be fetched too (default false).
Corresponds to the JSON property recurseSubmodules
2945 2946 2947 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2945 def recurse_submodules @recurse_submodules end |
#repository ⇒ Google::Apis::CloudbuildV1::GitSourceRepository
A repository for a git source.
Corresponds to the JSON property repository
2951 2952 2953 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2951 def repository @repository end |
#revision ⇒ String
Required. The revision that we will fetch the repo at.
Corresponds to the JSON property revision
2956 2957 2958 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2956 def revision @revision end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2963 2964 2965 2966 2967 2968 2969 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2963 def update!(**args) @depth = args[:depth] if args.key?(:depth) @dest_path = args[:dest_path] if args.key?(:dest_path) @recurse_submodules = args[:recurse_submodules] if args.key?(:recurse_submodules) @repository = args[:repository] if args.key?(:repository) @revision = args[:revision] if args.key?(:revision) end |