Class: Google::Apis::CloudbuildV1::MavenArtifact

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

A Maven artifact to upload to Artifact Registry upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MavenArtifact

Returns a new instance of MavenArtifact.



3314
3315
3316
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3314

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_idString

Maven artifactId value used when uploading the artifact to Artifact Registry. Corresponds to the JSON property artifactId

Returns:

  • (String)


3279
3280
3281
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3279

def artifact_id
  @artifact_id
end

#deploy_folderString

Optional. Path to a folder containing the files to upload to Artifact Registry. This can be either an absolute path, e.g. /workspace/my-app/target/, or a relative path from /workspace, e.g. my-app/target/. This field is mutually exclusive with the path field. Corresponds to the JSON property deployFolder

Returns:

  • (String)


3287
3288
3289
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3287

def deploy_folder
  @deploy_folder
end

#group_idString

Maven groupId value used when uploading the artifact to Artifact Registry. Corresponds to the JSON property groupId

Returns:

  • (String)


3292
3293
3294
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3292

def group_id
  @group_id
end

#pathString

Optional. Path to an artifact in the build's workspace to be uploaded to Artifact Registry. This can be either an absolute path, e.g. /workspace/my-app/ target/my-app-1.0.SNAPSHOT.jar or a relative path from /workspace, e.g. my-app/ target/my-app-1.0.SNAPSHOT.jar. Corresponds to the JSON property path

Returns:

  • (String)


3300
3301
3302
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3300

def path
  @path
end

#repositoryString

Artifact Registry repository, in the form "https://$REGION-maven.pkg.dev/$ PROJECT/$REPOSITORY" Artifact in the workspace specified by path will be uploaded to Artifact Registry with this location as a prefix. Corresponds to the JSON property repository

Returns:

  • (String)


3307
3308
3309
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3307

def repository
  @repository
end

#versionString

Maven version value used when uploading the artifact to Artifact Registry. Corresponds to the JSON property version

Returns:

  • (String)


3312
3313
3314
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3312

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3319
3320
3321
3322
3323
3324
3325
3326
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3319

def update!(**args)
  @artifact_id = args[:artifact_id] if args.key?(:artifact_id)
  @deploy_folder = args[:deploy_folder] if args.key?(:deploy_folder)
  @group_id = args[:group_id] if args.key?(:group_id)
  @path = args[:path] if args.key?(:path)
  @repository = args[:repository] if args.key?(:repository)
  @version = args[:version] if args.key?(:version)
end