Class: Google::Apis::CloudbuildV1::NpmPackage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

Npm package to upload to Artifact Registry upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NpmPackage

Returns a new instance of NpmPackage.



3390
3391
3392
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3390

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#package_pathString

Optional. Path to the package.json. e.g. workspace/path/to/package Only one of archive or package_path can be specified. Corresponds to the JSON property packagePath

Returns:

  • (String)


3381
3382
3383
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3381

def package_path
  @package_path
end

#repositoryString

Artifact Registry repository, in the form "https://$REGION-npm.pkg.dev/$ PROJECT/$REPOSITORY" Npm package in the workspace specified by path will be zipped and uploaded to Artifact Registry with this location as a prefix. Corresponds to the JSON property repository

Returns:

  • (String)


3388
3389
3390
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3388

def repository
  @repository
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3395
3396
3397
3398
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3395

def update!(**args)
  @package_path = args[:package_path] if args.key?(:package_path)
  @repository = args[:repository] if args.key?(:repository)
end