Class: Google::Apis::CloudbuildV1::Oci

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

OCI image to upload to Artifact Registry upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Oci

Returns a new instance of Oci.



3552
3553
3554
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3552

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fileString

Required. Path on the local file system where to find the container to upload. e.g. /workspace/my-image.tar Corresponds to the JSON property file

Returns:

  • (String)


3539
3540
3541
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3539

def file
  @file
end

#registry_pathString

Required. Registry path to upload the container to. e.g. us-east1-docker.pkg. dev/my-project/my-repo/my-image Corresponds to the JSON property registryPath

Returns:

  • (String)


3545
3546
3547
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3545

def registry_path
  @registry_path
end

#tagsArray<String>

Optional. Tags to apply to the uploaded image. e.g. latest, 1.0.0 Corresponds to the JSON property tags

Returns:

  • (Array<String>)


3550
3551
3552
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3550

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3557
3558
3559
3560
3561
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3557

def update!(**args)
  @file = args[:file] if args.key?(:file)
  @registry_path = args[:registry_path] if args.key?(:registry_path)
  @tags = args[:tags] if args.key?(:tags)
end