Class: Google::Apis::CloudbuildV1::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::OperationMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
Represents the metadata of the long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#cancel_requested ⇒ Boolean
(also: #cancel_requested?)
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#status_detail ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
3506 3507 3508 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3506 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
3470 3471 3472 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3470 def api_version @api_version end |
#cancel_requested ⇒ Boolean Also known as: cancel_requested?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have been cancelled successfully have google.
longrunning.Operation.error value with a google.rpc.Status.code of 1,
corresponding to Code.CANCELLED.
Corresponds to the JSON property cancelRequested
3478 3479 3480 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3478 def cancel_requested @cancel_requested end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
3484 3485 3486 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3484 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
3489 3490 3491 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3489 def end_time @end_time end |
#status_detail ⇒ String
Output only. Human-readable status of the operation, if any.
Corresponds to the JSON property statusDetail
3494 3495 3496 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3494 def status_detail @status_detail end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
3499 3500 3501 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3499 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
3504 3505 3506 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3504 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3511 3512 3513 3514 3515 3516 3517 3518 3519 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3511 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @cancel_requested = args[:cancel_requested] if args.key?(:cancel_requested) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @status_detail = args[:status_detail] if args.key?(:status_detail) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |