Class: Google::Apis::CloudbuildV1::PrivatePoolV1Config

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

Configuration for a V1 PrivatePool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrivatePoolV1Config

Returns a new instance of PrivatePoolV1Config.



3709
3710
3711
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3709

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#network_configGoogle::Apis::CloudbuildV1::NetworkConfig

Defines the network configuration for the pool. Corresponds to the JSON property networkConfig



3697
3698
3699
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3697

def network_config
  @network_config
end

#private_service_connectGoogle::Apis::CloudbuildV1::PrivateServiceConnect

Defines the Private Service Connect network configuration for the pool. Corresponds to the JSON property privateServiceConnect



3702
3703
3704
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3702

def private_service_connect
  @private_service_connect
end

#worker_configGoogle::Apis::CloudbuildV1::WorkerConfig

Defines the configuration to be used for creating workers in the pool. Corresponds to the JSON property workerConfig



3707
3708
3709
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3707

def worker_config
  @worker_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3714
3715
3716
3717
3718
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3714

def update!(**args)
  @network_config = args[:network_config] if args.key?(:network_config)
  @private_service_connect = args[:private_service_connect] if args.key?(:private_service_connect)
  @worker_config = args[:worker_config] if args.key?(:worker_config)
end