Class: Google::Apis::CloudbuildV1::PushFilter

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

Push contains filter properties for matching GitHub git pushes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PushFilter

Returns a new instance of PushFilter.



3923
3924
3925
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3923

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#branchString

Regexes matching branches to build. The syntax of the regular expressions accepted is the syntax accepted by RE2 and described at https://github.com/ google/re2/wiki/Syntax Corresponds to the JSON property branch

Returns:

  • (String)


3907
3908
3909
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3907

def branch
  @branch
end

#invert_regexBoolean Also known as: invert_regex?

When true, only trigger a build if the revision regex does NOT match the git_ref regex. Corresponds to the JSON property invertRegex

Returns:

  • (Boolean)


3913
3914
3915
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3913

def invert_regex
  @invert_regex
end

#tagString

Regexes matching tags to build. The syntax of the regular expressions accepted is the syntax accepted by RE2 and described at https://github.com/google/re2/ wiki/Syntax Corresponds to the JSON property tag

Returns:

  • (String)


3921
3922
3923
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3921

def tag
  @tag
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3928
3929
3930
3931
3932
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3928

def update!(**args)
  @branch = args[:branch] if args.key?(:branch)
  @invert_regex = args[:invert_regex] if args.key?(:invert_regex)
  @tag = args[:tag] if args.key?(:tag)
end