Class: Google::Apis::CloudbuildV1::Results
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::Results
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
Artifacts created by the build pipeline.
Instance Attribute Summary collapse
-
#artifact_manifest ⇒ String
Path to the artifact manifest for non-container artifacts uploaded to Cloud Storage.
-
#artifact_timing ⇒ Google::Apis::CloudbuildV1::TimeSpan
Start and end times for a build execution phase.
-
#build_step_images ⇒ Array<String>
List of build step digests, in the order corresponding to build step indices.
-
#build_step_outputs ⇒ Array<String>
List of build step outputs, produced by builder images, in the order corresponding to build step indices.
-
#build_step_results ⇒ Hash<String,Google::Apis::CloudbuildV1::BuildStepResults>
Results for build steps.
-
#generic_artifacts ⇒ Array<Google::Apis::CloudbuildV1::UploadedGenericArtifact>
Output only.
-
#go_modules ⇒ Array<Google::Apis::CloudbuildV1::UploadedGoModule>
Optional.
-
#images ⇒ Array<Google::Apis::CloudbuildV1::BuiltImage>
Container images that were built as a part of the build.
-
#maven_artifacts ⇒ Array<Google::Apis::CloudbuildV1::UploadedMavenArtifact>
Maven artifacts uploaded to Artifact Registry at the end of the build.
-
#npm_packages ⇒ Array<Google::Apis::CloudbuildV1::UploadedNpmPackage>
Npm packages uploaded to Artifact Registry at the end of the build.
-
#num_artifacts ⇒ Fixnum
Number of non-container artifacts uploaded to Cloud Storage.
-
#python_packages ⇒ Array<Google::Apis::CloudbuildV1::UploadedPythonPackage>
Python artifacts uploaded to Artifact Registry at the end of the build.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Results
constructor
A new instance of Results.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Results
Returns a new instance of Results.
4183 4184 4185 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_manifest ⇒ String
Path to the artifact manifest for non-container artifacts uploaded to Cloud
Storage. Only populated when artifacts are uploaded to Cloud Storage.
Corresponds to the JSON property artifactManifest
4119 4120 4121 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4119 def artifact_manifest @artifact_manifest end |
#artifact_timing ⇒ Google::Apis::CloudbuildV1::TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property artifactTiming
4124 4125 4126 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4124 def artifact_timing @artifact_timing end |
#build_step_images ⇒ Array<String>
List of build step digests, in the order corresponding to build step indices.
Corresponds to the JSON property buildStepImages
4129 4130 4131 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4129 def build_step_images @build_step_images end |
#build_step_outputs ⇒ Array<String>
List of build step outputs, produced by builder images, in the order
corresponding to build step indices. Cloud Builders can produce this output by writing to $
BUILDER_OUTPUT/output. Only the first 50KB of data is stored. Note that the $
BUILDER_OUTPUT variable is read-only and can't be substituted.
Corresponds to the JSON property buildStepOutputs
4138 4139 4140 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4138 def build_step_outputs @build_step_outputs end |
#build_step_results ⇒ Hash<String,Google::Apis::CloudbuildV1::BuildStepResults>
Results for build steps. step_id ->
Corresponds to the JSON property buildStepResults
4143 4144 4145 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4143 def build_step_results @build_step_results end |
#generic_artifacts ⇒ Array<Google::Apis::CloudbuildV1::UploadedGenericArtifact>
Output only. Generic artifacts uploaded to Artifact Registry at the end of the
build.
Corresponds to the JSON property genericArtifacts
4149 4150 4151 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4149 def generic_artifacts @generic_artifacts end |
#go_modules ⇒ Array<Google::Apis::CloudbuildV1::UploadedGoModule>
Optional. Go module artifacts uploaded to Artifact Registry at the end of the
build.
Corresponds to the JSON property goModules
4155 4156 4157 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4155 def go_modules @go_modules end |
#images ⇒ Array<Google::Apis::CloudbuildV1::BuiltImage>
Container images that were built as a part of the build.
Corresponds to the JSON property images
4160 4161 4162 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4160 def images @images end |
#maven_artifacts ⇒ Array<Google::Apis::CloudbuildV1::UploadedMavenArtifact>
Maven artifacts uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property mavenArtifacts
4165 4166 4167 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4165 def maven_artifacts @maven_artifacts end |
#npm_packages ⇒ Array<Google::Apis::CloudbuildV1::UploadedNpmPackage>
Npm packages uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property npmPackages
4170 4171 4172 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4170 def npm_packages @npm_packages end |
#num_artifacts ⇒ Fixnum
Number of non-container artifacts uploaded to Cloud Storage. Only populated
when artifacts are uploaded to Cloud Storage.
Corresponds to the JSON property numArtifacts
4176 4177 4178 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4176 def num_artifacts @num_artifacts end |
#python_packages ⇒ Array<Google::Apis::CloudbuildV1::UploadedPythonPackage>
Python artifacts uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property pythonPackages
4181 4182 4183 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4181 def python_packages @python_packages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4188 def update!(**args) @artifact_manifest = args[:artifact_manifest] if args.key?(:artifact_manifest) @artifact_timing = args[:artifact_timing] if args.key?(:artifact_timing) @build_step_images = args[:build_step_images] if args.key?(:build_step_images) @build_step_outputs = args[:build_step_outputs] if args.key?(:build_step_outputs) @build_step_results = args[:build_step_results] if args.key?(:build_step_results) @generic_artifacts = args[:generic_artifacts] if args.key?(:generic_artifacts) @go_modules = args[:go_modules] if args.key?(:go_modules) @images = args[:images] if args.key?(:images) @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts) @npm_packages = args[:npm_packages] if args.key?(:npm_packages) @num_artifacts = args[:num_artifacts] if args.key?(:num_artifacts) @python_packages = args[:python_packages] if args.key?(:python_packages) end |