Class: Google::Apis::CloudbuildV1::SecretManagerSecret

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

Pairs a secret environment variable with a SecretVersion in Secret Manager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecretManagerSecret

Returns a new instance of SecretManagerSecret.



4315
4316
4317
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4315

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#envString

Environment variable name to associate with the secret. Secret environment variables must be unique across all of a build's secrets, and must be used by at least one build step. Corresponds to the JSON property env

Returns:

  • (String)


4308
4309
4310
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4308

def env
  @env
end

#version_nameString

Resource name of the SecretVersion. In format: projects//secrets//versions/* Corresponds to the JSON property versionName

Returns:

  • (String)


4313
4314
4315
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4313

def version_name
  @version_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4320
4321
4322
4323
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4320

def update!(**args)
  @env = args[:env] if args.key?(:env)
  @version_name = args[:version_name] if args.key?(:version_name)
end