Class: Google::Apis::CloudbuildV1::UploadedGenericArtifact

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

A generic artifact uploaded to Artifact Registry using the GenericArtifact directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UploadedGenericArtifact

Returns a new instance of UploadedGenericArtifact.



4834
4835
4836
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4834

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_fingerprintGoogle::Apis::CloudbuildV1::FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property artifactFingerprint



4811
4812
4813
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4811

def artifact_fingerprint
  @artifact_fingerprint
end

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


4816
4817
4818
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4816

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesHash<String,Google::Apis::CloudbuildV1::FileHashes>

Output only. The file hashes that make up the generic artifact. Corresponds to the JSON property fileHashes

Returns:



4821
4822
4823
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4821

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::CloudbuildV1::TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



4826
4827
4828
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4826

def push_timing
  @push_timing
end

#uriString

Output only. URI of the uploaded artifact. Ex: projects/p1/locations/us/ repositories/r1/packages/p1/versions/v1 Corresponds to the JSON property uri

Returns:

  • (String)


4832
4833
4834
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4832

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4839
4840
4841
4842
4843
4844
4845
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4839

def update!(**args)
  @artifact_fingerprint = args[:artifact_fingerprint] if args.key?(:artifact_fingerprint)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end