Class: Google::Apis::CloudbuildV1::UploadedMavenArtifact

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

A Maven artifact uploaded using the MavenArtifact directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UploadedMavenArtifact

Returns a new instance of UploadedMavenArtifact.



4912
4913
4914
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4912

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


4894
4895
4896
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4894

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::CloudbuildV1::FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



4900
4901
4902
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4900

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::CloudbuildV1::TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



4905
4906
4907
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4905

def push_timing
  @push_timing
end

#uriString

URI of the uploaded artifact. Corresponds to the JSON property uri

Returns:

  • (String)


4910
4911
4912
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4910

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4917
4918
4919
4920
4921
4922
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4917

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end