Class: Google::Apis::CloudbuildV1::UploadedNpmPackage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

An npm package uploaded to Artifact Registry using the NpmPackage directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UploadedNpmPackage

Returns a new instance of UploadedNpmPackage.



4950
4951
4952
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4950

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


4932
4933
4934
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4932

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::CloudbuildV1::FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



4938
4939
4940
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4938

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::CloudbuildV1::TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



4943
4944
4945
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4943

def push_timing
  @push_timing
end

#uriString

URI of the uploaded npm package. Corresponds to the JSON property uri

Returns:

  • (String)


4948
4949
4950
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4948

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4955
4956
4957
4958
4959
4960
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4955

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end