Class: Google::Apis::CloudbuildV1::Volume
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::Volume
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
Volume describes a Docker container volume which is mounted into build steps in order to persist files across build step execution.
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the volume to mount.
-
#path ⇒ String
Path at which to mount the volume.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Volume
constructor
A new instance of Volume.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Volume
Returns a new instance of Volume.
5020 5021 5022 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 5020 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of the volume to mount. Volume names must be unique per build step and
must be valid names for Docker volumes. Each named volume must be used by at
least two build steps.
Corresponds to the JSON property name
5011 5012 5013 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 5011 def name @name end |
#path ⇒ String
Path at which to mount the volume. Paths must be absolute and cannot conflict
with other volume paths on the same build step or with certain reserved volume
paths.
Corresponds to the JSON property path
5018 5019 5020 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 5018 def path @path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5025 5026 5027 5028 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 5025 def update!(**args) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) end |