Class: Google::Apis::CloudbuildV1::Artifacts
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::Artifacts
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
Artifacts produced by a build that should be uploaded upon successful completion of all build steps.
Instance Attribute Summary collapse
-
#go_modules ⇒ Array<Google::Apis::CloudbuildV1::GoModule>
Optional.
-
#images ⇒ Array<String>
A list of images to be pushed upon the successful completion of all build steps.
-
#maven_artifacts ⇒ Array<Google::Apis::CloudbuildV1::MavenArtifact>
A list of Maven artifacts to be uploaded to Artifact Registry upon successful completion of all build steps.
-
#npm_packages ⇒ Array<Google::Apis::CloudbuildV1::NpmPackage>
A list of npm packages to be uploaded to Artifact Registry upon successful completion of all build steps.
-
#objects ⇒ Google::Apis::CloudbuildV1::ArtifactObjects
Files in the workspace to upload to Cloud Storage upon successful completion of all build steps.
-
#python_packages ⇒ Array<Google::Apis::CloudbuildV1::PythonPackage>
A list of Python packages to be uploaded to Artifact Registry upon successful completion of all build steps.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Artifacts
constructor
A new instance of Artifacts.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Artifacts
Returns a new instance of Artifacts.
229 230 231 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 229 def initialize(**args) update!(**args) end |
Instance Attribute Details
#go_modules ⇒ Array<Google::Apis::CloudbuildV1::GoModule>
Optional. A list of Go modules to be uploaded to Artifact Registry upon
successful completion of all build steps. If any objects fail to be pushed,
the build is marked FAILURE.
Corresponds to the JSON property goModules
186 187 188 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 186 def go_modules @go_modules end |
#images ⇒ Array<String>
A list of images to be pushed upon the successful completion of all build
steps. The images will be pushed using the builder service account's
credentials. The digests of the pushed images will be stored in the Build
resource's results field. If any of the images fail to be pushed, the build is
marked FAILURE.
Corresponds to the JSON property images
195 196 197 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 195 def images @images end |
#maven_artifacts ⇒ Array<Google::Apis::CloudbuildV1::MavenArtifact>
A list of Maven artifacts to be uploaded to Artifact Registry upon successful
completion of all build steps. Artifacts in the workspace matching specified
paths globs will be uploaded to the specified Artifact Registry repository
using the builder service account's credentials. If any artifacts fail to be
pushed, the build is marked FAILURE.
Corresponds to the JSON property mavenArtifacts
204 205 206 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 204 def maven_artifacts @maven_artifacts end |
#npm_packages ⇒ Array<Google::Apis::CloudbuildV1::NpmPackage>
A list of npm packages to be uploaded to Artifact Registry upon successful
completion of all build steps. Npm packages in the specified paths will be
uploaded to the specified Artifact Registry repository using the builder
service account's credentials. If any packages fail to be pushed, the build is
marked FAILURE.
Corresponds to the JSON property npmPackages
213 214 215 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 213 def npm_packages @npm_packages end |
#objects ⇒ Google::Apis::CloudbuildV1::ArtifactObjects
Files in the workspace to upload to Cloud Storage upon successful completion
of all build steps.
Corresponds to the JSON property objects
219 220 221 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 219 def objects @objects end |
#python_packages ⇒ Array<Google::Apis::CloudbuildV1::PythonPackage>
A list of Python packages to be uploaded to Artifact Registry upon successful
completion of all build steps. The build service account credentials will be
used to perform the upload. If any objects fail to be pushed, the build is
marked FAILURE.
Corresponds to the JSON property pythonPackages
227 228 229 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 227 def python_packages @python_packages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
234 235 236 237 238 239 240 241 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 234 def update!(**args) @go_modules = args[:go_modules] if args.key?(:go_modules) @images = args[:images] if args.key?(:images) @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts) @npm_packages = args[:npm_packages] if args.key?(:npm_packages) @objects = args[:objects] if args.key?(:objects) @python_packages = args[:python_packages] if args.key?(:python_packages) end |