Class: Google::Apis::CloudbuildV1::BitbucketServerConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

BitbucketServerConfig represents the configuration for a Bitbucket Server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BitbucketServerConfig

Returns a new instance of BitbucketServerConfig.



485
486
487
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 485

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_keyString

Required. Immutable. API Key that will be attached to webhook. Once this field has been set, it cannot be changed. If you need to change it, please create another BitbucketServerConfig. Corresponds to the JSON property apiKey

Returns:

  • (String)


415
416
417
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 415

def api_key
  @api_key
end

#connected_repositoriesArray<Google::Apis::CloudbuildV1::BitbucketServerRepositoryId>

Output only. Connected Bitbucket Server repositories for this config. Corresponds to the JSON property connectedRepositories



420
421
422
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 420

def connected_repositories
  @connected_repositories
end

#create_timeString

Time when the config was created. Corresponds to the JSON property createTime

Returns:

  • (String)


425
426
427
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 425

def create_time
  @create_time
end

#host_uriString

Required. Immutable. The URI of the Bitbucket Server host. Once this field has been set, it cannot be changed. If you need to change it, please create another BitbucketServerConfig. Corresponds to the JSON property hostUri

Returns:

  • (String)


432
433
434
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 432

def host_uri
  @host_uri
end

#nameString

The resource name for the config. Corresponds to the JSON property name

Returns:

  • (String)


437
438
439
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 437

def name
  @name
end

#peered_networkString

Optional. The network to be used when reaching out to the Bitbucket Server instance. The VPC network must be enabled for private service connection. This should be set if the Bitbucket Server instance is hosted on-premises and not reachable by public internet. If this field is left empty, no network peering will occur and calls to the Bitbucket Server instance will be made over the public internet. Must be in the format projects/project/global/networks/ network`, whereprojectis a project number or id andnetworkis the name of a VPC network in the project. Corresponds to the JSON propertypeeredNetwork`

Returns:

  • (String)


449
450
451
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 449

def peered_network
  @peered_network
end

#peered_network_ip_rangeString

Immutable. IP range within the peered network. This is specified in CIDR notation with a slash and the subnet prefix size. You can optionally specify an IP address before the subnet prefix value. e.g. 192.168.0.0/29 would specify an IP range starting at 192.168.0.0 with a 29 bit prefix size. /16 would specify a prefix size of 16 bits, with an automatically determined IP within the peered VPC. If unspecified, a value of /24 will be used. The field only has an effect if peered_network is set. Corresponds to the JSON property peeredNetworkIpRange

Returns:

  • (String)


460
461
462
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 460

def peered_network_ip_range
  @peered_network_ip_range
end

#secretsGoogle::Apis::CloudbuildV1::BitbucketServerSecrets

BitbucketServerSecrets represents the secrets in Secret Manager for a Bitbucket Server. Corresponds to the JSON property secrets



466
467
468
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 466

def secrets
  @secrets
end

#ssl_caString

Optional. SSL certificate to use for requests to Bitbucket Server. The format should be PEM format but the extension can be one of .pem, .cer, or .crt. Corresponds to the JSON property sslCa

Returns:

  • (String)


472
473
474
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 472

def ssl_ca
  @ssl_ca
end

#usernameString

Username of the account Cloud Build will use on Bitbucket Server. Corresponds to the JSON property username

Returns:

  • (String)


477
478
479
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 477

def username
  @username
end

#webhook_keyString

Output only. UUID included in webhook requests. The UUID is used to look up the corresponding config. Corresponds to the JSON property webhookKey

Returns:

  • (String)


483
484
485
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 483

def webhook_key
  @webhook_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



490
491
492
493
494
495
496
497
498
499
500
501
502
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 490

def update!(**args)
  @api_key = args[:api_key] if args.key?(:api_key)
  @connected_repositories = args[:connected_repositories] if args.key?(:connected_repositories)
  @create_time = args[:create_time] if args.key?(:create_time)
  @host_uri = args[:host_uri] if args.key?(:host_uri)
  @name = args[:name] if args.key?(:name)
  @peered_network = args[:peered_network] if args.key?(:peered_network)
  @peered_network_ip_range = args[:peered_network_ip_range] if args.key?(:peered_network_ip_range)
  @secrets = args[:secrets] if args.key?(:secrets)
  @ssl_ca = args[:ssl_ca] if args.key?(:ssl_ca)
  @username = args[:username] if args.key?(:username)
  @webhook_key = args[:webhook_key] if args.key?(:webhook_key)
end