Class: Google::Apis::CloudbuildV1::BitbucketServerConnectedRepository

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

/ BitbucketServerConnectedRepository represents a connected Bitbucket Server / repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BitbucketServerConnectedRepository

Returns a new instance of BitbucketServerConnectedRepository.



515
516
517
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 515

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parentString

The name of the BitbucketServerConfig that added connected repository. Format: projects/project/locations/location/bitbucketServerConfigs/ config` Corresponds to the JSON propertyparent`

Returns:

  • (String)


497
498
499
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 497

def parent
  @parent
end

#repoGoogle::Apis::CloudbuildV1::BitbucketServerRepositoryId

BitbucketServerRepositoryId identifies a specific repository hosted on a Bitbucket Server. Corresponds to the JSON property repo



503
504
505
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 503

def repo
  @repo
end

#statusGoogle::Apis::CloudbuildV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



513
514
515
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 513

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



520
521
522
523
524
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 520

def update!(**args)
  @parent = args[:parent] if args.key?(:parent)
  @repo = args[:repo] if args.key?(:repo)
  @status = args[:status] if args.key?(:status)
end