Class: Google::Apis::CloudbuildV1::BitbucketServerSecrets
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::BitbucketServerSecrets
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
BitbucketServerSecrets represents the secrets in Secret Manager for a Bitbucket Server.
Instance Attribute Summary collapse
-
#admin_access_token_version_name ⇒ String
Required.
-
#read_access_token_version_name ⇒ String
Required.
-
#webhook_secret_version_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BitbucketServerSecrets
constructor
A new instance of BitbucketServerSecrets.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BitbucketServerSecrets
Returns a new instance of BitbucketServerSecrets.
644 645 646 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 644 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_access_token_version_name ⇒ String
Required. The resource name for the admin access token's secret version.
Corresponds to the JSON property adminAccessTokenVersionName
630 631 632 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 630 def admin_access_token_version_name @admin_access_token_version_name end |
#read_access_token_version_name ⇒ String
Required. The resource name for the read access token's secret version.
Corresponds to the JSON property readAccessTokenVersionName
635 636 637 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 635 def read_access_token_version_name @read_access_token_version_name end |
#webhook_secret_version_name ⇒ String
Required. Immutable. The resource name for the webhook secret's secret version.
Once this field has been set, it cannot be changed. If you need to change it,
please create another BitbucketServerConfig.
Corresponds to the JSON property webhookSecretVersionName
642 643 644 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 642 def webhook_secret_version_name @webhook_secret_version_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
649 650 651 652 653 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 649 def update!(**args) @admin_access_token_version_name = args[:admin_access_token_version_name] if args.key?(:admin_access_token_version_name) @read_access_token_version_name = args[:read_access_token_version_name] if args.key?(:read_access_token_version_name) @webhook_secret_version_name = args[:webhook_secret_version_name] if args.key?(:webhook_secret_version_name) end |