Class: Google::Apis::CloudbuildV1::BitbucketServerSecrets

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

BitbucketServerSecrets represents the secrets in Secret Manager for a Bitbucket Server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BitbucketServerSecrets

Returns a new instance of BitbucketServerSecrets.



626
627
628
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 626

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_access_token_version_nameString

Required. The resource name for the admin access token's secret version. Corresponds to the JSON property adminAccessTokenVersionName

Returns:

  • (String)


612
613
614
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 612

def admin_access_token_version_name
  @admin_access_token_version_name
end

#read_access_token_version_nameString

Required. The resource name for the read access token's secret version. Corresponds to the JSON property readAccessTokenVersionName

Returns:

  • (String)


617
618
619
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 617

def read_access_token_version_name
  @read_access_token_version_name
end

#webhook_secret_version_nameString

Required. Immutable. The resource name for the webhook secret's secret version. Once this field has been set, it cannot be changed. If you need to change it, please create another BitbucketServerConfig. Corresponds to the JSON property webhookSecretVersionName

Returns:

  • (String)


624
625
626
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 624

def webhook_secret_version_name
  @webhook_secret_version_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



631
632
633
634
635
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 631

def update!(**args)
  @admin_access_token_version_name = args[:admin_access_token_version_name] if args.key?(:admin_access_token_version_name)
  @read_access_token_version_name = args[:read_access_token_version_name] if args.key?(:read_access_token_version_name)
  @webhook_secret_version_name = args[:webhook_secret_version_name] if args.key?(:webhook_secret_version_name)
end