Class: Google::Apis::CloudbuildV1::BuildApproval
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::BuildApproval
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
BuildApproval describes a build's approval configuration, state, and result.
Instance Attribute Summary collapse
-
#config ⇒ Google::Apis::CloudbuildV1::ApprovalConfig
ApprovalConfig describes configuration for manual approval of a build.
-
#result ⇒ Google::Apis::CloudbuildV1::ApprovalResult
ApprovalResult describes the decision and associated metadata of a manual approval of a build.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BuildApproval
constructor
A new instance of BuildApproval.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BuildApproval
Returns a new instance of BuildApproval.
951 952 953 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 951 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config ⇒ Google::Apis::CloudbuildV1::ApprovalConfig
ApprovalConfig describes configuration for manual approval of a build.
Corresponds to the JSON property config
938 939 940 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 938 def config @config end |
#result ⇒ Google::Apis::CloudbuildV1::ApprovalResult
ApprovalResult describes the decision and associated metadata of a manual
approval of a build.
Corresponds to the JSON property result
944 945 946 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 944 def result @result end |
#state ⇒ String
Output only. The state of this build's approval.
Corresponds to the JSON property state
949 950 951 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 949 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
956 957 958 959 960 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 956 def update!(**args) @config = args[:config] if args.key?(:config) @result = args[:result] if args.key?(:result) @state = args[:state] if args.key?(:state) end |