Class: Google::Apis::CloudbuildV1::BuiltImage
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::BuiltImage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
An image built by the pipeline.
Instance Attribute Summary collapse
-
#artifact_registry_package ⇒ String
Output only.
-
#digest ⇒ String
Docker Registry 2.0 digest.
-
#name ⇒ String
Name used to push the container image to Google Container Registry, as presented to
docker push. -
#oci_media_type ⇒ String
Output only.
-
#push_timing ⇒ Google::Apis::CloudbuildV1::TimeSpan
Start and end times for a build execution phase.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BuiltImage
constructor
A new instance of BuiltImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BuiltImage
Returns a new instance of BuiltImage.
1607 1608 1609 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 1607 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
1583 1584 1585 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 1583 def artifact_registry_package @artifact_registry_package end |
#digest ⇒ String
Docker Registry 2.0 digest.
Corresponds to the JSON property digest
1588 1589 1590 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 1588 def digest @digest end |
#name ⇒ String
Name used to push the container image to Google Container Registry, as
presented to docker push.
Corresponds to the JSON property name
1594 1595 1596 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 1594 def name @name end |
#oci_media_type ⇒ String
Output only. The OCI media type of the artifact. Non-OCI images, such as
Docker images, will have an unspecified value.
Corresponds to the JSON property ociMediaType
1600 1601 1602 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 1600 def oci_media_type @oci_media_type end |
#push_timing ⇒ Google::Apis::CloudbuildV1::TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
1605 1606 1607 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 1605 def push_timing @push_timing end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1612 1613 1614 1615 1616 1617 1618 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 1612 def update!(**args) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @digest = args[:digest] if args.key?(:digest) @name = args[:name] if args.key?(:name) @oci_media_type = args[:oci_media_type] if args.key?(:oci_media_type) @push_timing = args[:push_timing] if args.key?(:push_timing) end |