Class: Google::Apis::CloudbuildV1::BuiltImage
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::BuiltImage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
An image built by the pipeline.
Instance Attribute Summary collapse
-
#artifact_registry_package ⇒ String
Output only.
-
#digest ⇒ String
Docker Registry 2.0 digest.
-
#name ⇒ String
Name used to push the container image to Google Container Registry, as presented to
docker push. -
#push_timing ⇒ Google::Apis::CloudbuildV1::TimeSpan
Start and end times for a build execution phase.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BuiltImage
constructor
A new instance of BuiltImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BuiltImage
Returns a new instance of BuiltImage.
1558 1559 1560 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 1558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
1540 1541 1542 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 1540 def artifact_registry_package @artifact_registry_package end |
#digest ⇒ String
Docker Registry 2.0 digest.
Corresponds to the JSON property digest
1545 1546 1547 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 1545 def digest @digest end |
#name ⇒ String
Name used to push the container image to Google Container Registry, as
presented to docker push.
Corresponds to the JSON property name
1551 1552 1553 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 1551 def name @name end |
#push_timing ⇒ Google::Apis::CloudbuildV1::TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
1556 1557 1558 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 1556 def push_timing @push_timing end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1563 1564 1565 1566 1567 1568 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 1563 def update!(**args) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @digest = args[:digest] if args.key?(:digest) @name = args[:name] if args.key?(:name) @push_timing = args[:push_timing] if args.key?(:push_timing) end |