Class: Google::Apis::CloudbuildV1::Dependency

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

A dependency that the Cloud Build worker will fetch before executing user steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Dependency

Returns a new instance of Dependency.



2009
2010
2011
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2009

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emptyBoolean Also known as: empty?

If set to true disable all dependency fetching (ignoring the default source as well). Corresponds to the JSON property empty

Returns:

  • (Boolean)


2001
2002
2003
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2001

def empty
  @empty
end

#git_sourceGoogle::Apis::CloudbuildV1::GitSourceDependency

Represents a git repository as a build dependency. Corresponds to the JSON property gitSource



2007
2008
2009
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2007

def git_source
  @git_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2014
2015
2016
2017
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2014

def update!(**args)
  @empty = args[:empty] if args.key?(:empty)
  @git_source = args[:git_source] if args.key?(:git_source)
end