Class: Google::Apis::CloudbuildV1::DeveloperConnectConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

This config defines the location of a source through Developer Connect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeveloperConnectConfig

Returns a new instance of DeveloperConnectConfig.



2041
2042
2043
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2041

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dirString

Required. Directory, relative to the source root, in which to run the build. Corresponds to the JSON property dir

Returns:

  • (String)


2027
2028
2029
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2027

def dir
  @dir
end

Required. The Developer Connect Git repository link, formatted as projects/*/ locations/*/connections/*/gitRepositoryLink/*. Corresponds to the JSON property gitRepositoryLink

Returns:

  • (String)


2033
2034
2035
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2033

def git_repository_link
  @git_repository_link
end

#revisionString

Required. The revision to fetch from the Git repository such as a branch, a tag, a commit SHA, or any Git ref. Corresponds to the JSON property revision

Returns:

  • (String)


2039
2040
2041
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2039

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2046
2047
2048
2049
2050
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2046

def update!(**args)
  @dir = args[:dir] if args.key?(:dir)
  @git_repository_link = args[:git_repository_link] if args.key?(:git_repository_link)
  @revision = args[:revision] if args.key?(:revision)
end