Class: Google::Apis::CloudbuildV1::FileHashes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileHashes

Returns a new instance of FileHashes.



2199
2200
2201
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2199

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_hashArray<Google::Apis::CloudbuildV1::HashProp>

Collection of file hashes. Corresponds to the JSON property fileHash



2197
2198
2199
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2197

def file_hash
  @file_hash
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2204
2205
2206
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2204

def update!(**args)
  @file_hash = args[:file_hash] if args.key?(:file_hash)
end