Class: Google::Apis::CloudbuildV1::GitFileSource
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::GitFileSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
GitFileSource describes a file within a (possibly remote) code repository.
Instance Attribute Summary collapse
-
#bitbucket_server_config ⇒ String
The full resource name of the bitbucket server config.
-
#github_enterprise_config ⇒ String
The full resource name of the github enterprise config.
-
#path ⇒ String
The path of the file, with the repo root as the root of the path.
-
#repo_type ⇒ String
See RepoType above.
-
#repository ⇒ String
The fully qualified resource name of the Repos API repository.
-
#revision ⇒ String
The branch, tag, arbitrary ref, or SHA version of the repo to use when resolving the filename (optional).
-
#uri ⇒ String
The URI of the repo.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GitFileSource
constructor
A new instance of GitFileSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GitFileSource
Returns a new instance of GitFileSource.
2341 2342 2343 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2341 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bitbucket_server_config ⇒ String
The full resource name of the bitbucket server config. Format: projects/
project/locations/location/bitbucketServerConfigs/id`.
Corresponds to the JSON propertybitbucketServerConfig`
2298 2299 2300 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2298 def bitbucket_server_config @bitbucket_server_config end |
#github_enterprise_config ⇒ String
The full resource name of the github enterprise config. Format: projects/
project/locations/location/githubEnterpriseConfigs/id. `projects/`
project`/githubEnterpriseConfigs/`id.
Corresponds to the JSON property githubEnterpriseConfig
2305 2306 2307 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2305 def github_enterprise_config @github_enterprise_config end |
#path ⇒ String
The path of the file, with the repo root as the root of the path.
Corresponds to the JSON property path
2310 2311 2312 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2310 def path @path end |
#repo_type ⇒ String
See RepoType above.
Corresponds to the JSON property repoType
2315 2316 2317 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2315 def repo_type @repo_type end |
#repository ⇒ String
The fully qualified resource name of the Repos API repository. Either URI or
repository can be specified. If unspecified, the repo from which the trigger
invocation originated is assumed to be the repo from which to read the
specified path.
Corresponds to the JSON property repository
2323 2324 2325 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2323 def repository @repository end |
#revision ⇒ String
The branch, tag, arbitrary ref, or SHA version of the repo to use when
resolving the filename (optional). This field respects the same syntax/
resolution as described here: https://git-scm.com/docs/gitrevisions If
unspecified, the revision from which the trigger invocation originated is
assumed to be the revision from which to read the specified path.
Corresponds to the JSON property revision
2332 2333 2334 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2332 def revision @revision end |
#uri ⇒ String
The URI of the repo. Either uri or repository can be specified. If unspecified,
the repo from which the trigger invocation originated is assumed to be the
repo from which to read the specified path.
Corresponds to the JSON property uri
2339 2340 2341 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2339 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2346 2347 2348 2349 2350 2351 2352 2353 2354 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2346 def update!(**args) @bitbucket_server_config = args[:bitbucket_server_config] if args.key?(:bitbucket_server_config) @github_enterprise_config = args[:github_enterprise_config] if args.key?(:github_enterprise_config) @path = args[:path] if args.key?(:path) @repo_type = args[:repo_type] if args.key?(:repo_type) @repository = args[:repository] if args.key?(:repository) @revision = args[:revision] if args.key?(:revision) @uri = args[:uri] if args.key?(:uri) end |