Class: Google::Apis::CloudbuildV1::GitFileSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

GitFileSource describes a file within a (possibly remote) code repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitFileSource

Returns a new instance of GitFileSource.



2334
2335
2336
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2334

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bitbucket_server_configString

The full resource name of the bitbucket server config. Format: projects/ project/locations/location/bitbucketServerConfigs/id`. Corresponds to the JSON propertybitbucketServerConfig`

Returns:

  • (String)


2291
2292
2293
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2291

def bitbucket_server_config
  @bitbucket_server_config
end

#github_enterprise_configString

The full resource name of the github enterprise config. Format: projects/ project/locations/location/githubEnterpriseConfigs/id. `projects/` project`/githubEnterpriseConfigs/`id. Corresponds to the JSON property githubEnterpriseConfig

Returns:

  • (String)


2298
2299
2300
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2298

def github_enterprise_config
  @github_enterprise_config
end

#pathString

The path of the file, with the repo root as the root of the path. Corresponds to the JSON property path

Returns:

  • (String)


2303
2304
2305
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2303

def path
  @path
end

#repo_typeString

See RepoType above. Corresponds to the JSON property repoType

Returns:

  • (String)


2308
2309
2310
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2308

def repo_type
  @repo_type
end

#repositoryString

The fully qualified resource name of the Repos API repository. Either URI or repository can be specified. If unspecified, the repo from which the trigger invocation originated is assumed to be the repo from which to read the specified path. Corresponds to the JSON property repository

Returns:

  • (String)


2316
2317
2318
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2316

def repository
  @repository
end

#revisionString

The branch, tag, arbitrary ref, or SHA version of the repo to use when resolving the filename (optional). This field respects the same syntax/ resolution as described here: https://git-scm.com/docs/gitrevisions If unspecified, the revision from which the trigger invocation originated is assumed to be the revision from which to read the specified path. Corresponds to the JSON property revision

Returns:

  • (String)


2325
2326
2327
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2325

def revision
  @revision
end

#uriString

The URI of the repo. Either uri or repository can be specified. If unspecified, the repo from which the trigger invocation originated is assumed to be the repo from which to read the specified path. Corresponds to the JSON property uri

Returns:

  • (String)


2332
2333
2334
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2332

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2339
2340
2341
2342
2343
2344
2345
2346
2347
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2339

def update!(**args)
  @bitbucket_server_config = args[:bitbucket_server_config] if args.key?(:bitbucket_server_config)
  @github_enterprise_config = args[:github_enterprise_config] if args.key?(:github_enterprise_config)
  @path = args[:path] if args.key?(:path)
  @repo_type = args[:repo_type] if args.key?(:repo_type)
  @repository = args[:repository] if args.key?(:repository)
  @revision = args[:revision] if args.key?(:revision)
  @uri = args[:uri] if args.key?(:uri)
end