Class: Google::Apis::CloudbuildV1::GitFileSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

GitFileSource describes a file within a (possibly remote) code repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitFileSource

Returns a new instance of GitFileSource.



2223
2224
2225
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2223

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bitbucket_server_configString

The full resource name of the bitbucket server config. Format: projects/ project/locations/location/bitbucketServerConfigs/id`. Corresponds to the JSON propertybitbucketServerConfig`

Returns:

  • (String)


2180
2181
2182
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2180

def bitbucket_server_config
  @bitbucket_server_config
end

#github_enterprise_configString

The full resource name of the github enterprise config. Format: projects/ project/locations/location/githubEnterpriseConfigs/id. `projects/` project`/githubEnterpriseConfigs/`id. Corresponds to the JSON property githubEnterpriseConfig

Returns:

  • (String)


2187
2188
2189
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2187

def github_enterprise_config
  @github_enterprise_config
end

#pathString

The path of the file, with the repo root as the root of the path. Corresponds to the JSON property path

Returns:

  • (String)


2192
2193
2194
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2192

def path
  @path
end

#repo_typeString

See RepoType above. Corresponds to the JSON property repoType

Returns:

  • (String)


2197
2198
2199
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2197

def repo_type
  @repo_type
end

#repositoryString

The fully qualified resource name of the Repos API repository. Either URI or repository can be specified. If unspecified, the repo from which the trigger invocation originated is assumed to be the repo from which to read the specified path. Corresponds to the JSON property repository

Returns:

  • (String)


2205
2206
2207
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2205

def repository
  @repository
end

#revisionString

The branch, tag, arbitrary ref, or SHA version of the repo to use when resolving the filename (optional). This field respects the same syntax/ resolution as described here: https://git-scm.com/docs/gitrevisions If unspecified, the revision from which the trigger invocation originated is assumed to be the revision from which to read the specified path. Corresponds to the JSON property revision

Returns:

  • (String)


2214
2215
2216
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2214

def revision
  @revision
end

#uriString

The URI of the repo. Either uri or repository can be specified. If unspecified, the repo from which the trigger invocation originated is assumed to be the repo from which to read the specified path. Corresponds to the JSON property uri

Returns:

  • (String)


2221
2222
2223
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2221

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2228
2229
2230
2231
2232
2233
2234
2235
2236
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2228

def update!(**args)
  @bitbucket_server_config = args[:bitbucket_server_config] if args.key?(:bitbucket_server_config)
  @github_enterprise_config = args[:github_enterprise_config] if args.key?(:github_enterprise_config)
  @path = args[:path] if args.key?(:path)
  @repo_type = args[:repo_type] if args.key?(:repo_type)
  @repository = args[:repository] if args.key?(:repository)
  @revision = args[:revision] if args.key?(:revision)
  @uri = args[:uri] if args.key?(:uri)
end