Class: Google::Apis::CloudbuildV1::GitHubEnterpriseConfig
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::GitHubEnterpriseConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
GitHubEnterpriseConfig represents a configuration for a GitHub Enterprise server.
Instance Attribute Summary collapse
-
#app_id ⇒ Fixnum
Required.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#host_url ⇒ String
The URL of the github enterprise host the configuration is for.
-
#name ⇒ String
Identifier.
-
#peered_network ⇒ String
Optional.
-
#secrets ⇒ Google::Apis::CloudbuildV1::GitHubEnterpriseSecrets
GitHubEnterpriseSecrets represents the names of all necessary secrets in Secret Manager for a GitHub Enterprise server.
-
#ssl_ca ⇒ String
Optional.
-
#webhook_key ⇒ String
The key that should be attached to webhook calls to the ReceiveWebhook endpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GitHubEnterpriseConfig
constructor
A new instance of GitHubEnterpriseConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GitHubEnterpriseConfig
Returns a new instance of GitHubEnterpriseConfig.
2419 2420 2421 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2419 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_id ⇒ Fixnum
Required. The GitHub app id of the Cloud Build app on the GitHub Enterprise
server.
Corresponds to the JSON property appId
2366 2367 2368 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2366 def app_id @app_id end |
#create_time ⇒ String
Output only. Time when the installation was associated with the project.
Corresponds to the JSON property createTime
2371 2372 2373 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2371 def create_time @create_time end |
#display_name ⇒ String
Optional. Name to display for this config.
Corresponds to the JSON property displayName
2376 2377 2378 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2376 def display_name @display_name end |
#host_url ⇒ String
The URL of the github enterprise host the configuration is for.
Corresponds to the JSON property hostUrl
2381 2382 2383 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2381 def host_url @host_url end |
#name ⇒ String
Identifier. The full resource name for the GitHubEnterpriseConfig For example:
"projects/$project_id/locations/$location_id/githubEnterpriseConfigs/$
config_id"
Corresponds to the JSON property name
2388 2389 2390 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2388 def name @name end |
#peered_network ⇒ String
Optional. The network to be used when reaching out to the GitHub Enterprise
server. The VPC network must be enabled for private service connection. This
should be set if the GitHub Enterprise server is hosted on-premises and not
reachable by public internet. If this field is left empty, no network peering
will occur and calls to the GitHub Enterprise server will be made over the
public internet. Must be in the format projects/project/global/networks/
network`, whereprojectis a project number or id andnetworkis the name
of a VPC network in the project.
Corresponds to the JSON propertypeeredNetwork`
2400 2401 2402 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2400 def peered_network @peered_network end |
#secrets ⇒ Google::Apis::CloudbuildV1::GitHubEnterpriseSecrets
GitHubEnterpriseSecrets represents the names of all necessary secrets in
Secret Manager for a GitHub Enterprise server. Format is: projects//secrets/.
Corresponds to the JSON property secrets
2406 2407 2408 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2406 def secrets @secrets end |
#ssl_ca ⇒ String
Optional. SSL certificate to use for requests to GitHub Enterprise.
Corresponds to the JSON property sslCa
2411 2412 2413 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2411 def ssl_ca @ssl_ca end |
#webhook_key ⇒ String
The key that should be attached to webhook calls to the ReceiveWebhook
endpoint.
Corresponds to the JSON property webhookKey
2417 2418 2419 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2417 def webhook_key @webhook_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2424 def update!(**args) @app_id = args[:app_id] if args.key?(:app_id) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @host_url = args[:host_url] if args.key?(:host_url) @name = args[:name] if args.key?(:name) @peered_network = args[:peered_network] if args.key?(:peered_network) @secrets = args[:secrets] if args.key?(:secrets) @ssl_ca = args[:ssl_ca] if args.key?(:ssl_ca) @webhook_key = args[:webhook_key] if args.key?(:webhook_key) end |