Class: Google::Apis::CloudbuildV1::GitHubEnterpriseConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

GitHubEnterpriseConfig represents a configuration for a GitHub Enterprise server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitHubEnterpriseConfig

Returns a new instance of GitHubEnterpriseConfig.



2411
2412
2413
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2411

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_idFixnum

Required. The GitHub app id of the Cloud Build app on the GitHub Enterprise server. Corresponds to the JSON property appId

Returns:

  • (Fixnum)


2359
2360
2361
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2359

def app_id
  @app_id
end

#create_timeString

Output only. Time when the installation was associated with the project. Corresponds to the JSON property createTime

Returns:

  • (String)


2364
2365
2366
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2364

def create_time
  @create_time
end

#display_nameString

Optional. Name to display for this config. Corresponds to the JSON property displayName

Returns:

  • (String)


2369
2370
2371
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2369

def display_name
  @display_name
end

#host_urlString

The URL of the github enterprise host the configuration is for. Corresponds to the JSON property hostUrl

Returns:

  • (String)


2374
2375
2376
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2374

def host_url
  @host_url
end

#nameString

The full resource name for the GitHubEnterpriseConfig For example: "projects/$ project_id/locations/$location_id/githubEnterpriseConfigs/$config_id" Corresponds to the JSON property name

Returns:

  • (String)


2380
2381
2382
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2380

def name
  @name
end

#peered_networkString

Optional. The network to be used when reaching out to the GitHub Enterprise server. The VPC network must be enabled for private service connection. This should be set if the GitHub Enterprise server is hosted on-premises and not reachable by public internet. If this field is left empty, no network peering will occur and calls to the GitHub Enterprise server will be made over the public internet. Must be in the format projects/project/global/networks/ network`, whereprojectis a project number or id andnetworkis the name of a VPC network in the project. Corresponds to the JSON propertypeeredNetwork`

Returns:

  • (String)


2392
2393
2394
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2392

def peered_network
  @peered_network
end

#secretsGoogle::Apis::CloudbuildV1::GitHubEnterpriseSecrets

GitHubEnterpriseSecrets represents the names of all necessary secrets in Secret Manager for a GitHub Enterprise server. Format is: projects//secrets/. Corresponds to the JSON property secrets



2398
2399
2400
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2398

def secrets
  @secrets
end

#ssl_caString

Optional. SSL certificate to use for requests to GitHub Enterprise. Corresponds to the JSON property sslCa

Returns:

  • (String)


2403
2404
2405
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2403

def ssl_ca
  @ssl_ca
end

#webhook_keyString

The key that should be attached to webhook calls to the ReceiveWebhook endpoint. Corresponds to the JSON property webhookKey

Returns:

  • (String)


2409
2410
2411
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2409

def webhook_key
  @webhook_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2416

def update!(**args)
  @app_id = args[:app_id] if args.key?(:app_id)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @host_url = args[:host_url] if args.key?(:host_url)
  @name = args[:name] if args.key?(:name)
  @peered_network = args[:peered_network] if args.key?(:peered_network)
  @secrets = args[:secrets] if args.key?(:secrets)
  @ssl_ca = args[:ssl_ca] if args.key?(:ssl_ca)
  @webhook_key = args[:webhook_key] if args.key?(:webhook_key)
end