Class: Google::Apis::CloudbuildV1::GitHubEnterpriseSecrets

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

GitHubEnterpriseSecrets represents the names of all necessary secrets in Secret Manager for a GitHub Enterprise server. Format is: projects//secrets/.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitHubEnterpriseSecrets

Returns a new instance of GitHubEnterpriseSecrets.



2363
2364
2365
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2363

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#oauth_client_id_nameString

The resource name for the OAuth client ID secret in Secret Manager. Corresponds to the JSON property oauthClientIdName

Returns:

  • (String)


2326
2327
2328
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2326

def oauth_client_id_name
  @oauth_client_id_name
end

#oauth_client_id_version_nameString

The resource name for the OAuth client ID secret version in Secret Manager. Corresponds to the JSON property oauthClientIdVersionName

Returns:

  • (String)


2331
2332
2333
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2331

def oauth_client_id_version_name
  @oauth_client_id_version_name
end

#oauth_secret_nameString

The resource name for the OAuth secret in Secret Manager. Corresponds to the JSON property oauthSecretName

Returns:

  • (String)


2336
2337
2338
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2336

def oauth_secret_name
  @oauth_secret_name
end

#oauth_secret_version_nameString

The resource name for the OAuth secret secret version in Secret Manager. Corresponds to the JSON property oauthSecretVersionName

Returns:

  • (String)


2341
2342
2343
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2341

def oauth_secret_version_name
  @oauth_secret_version_name
end

#private_key_nameString

The resource name for the private key secret. Corresponds to the JSON property privateKeyName

Returns:

  • (String)


2346
2347
2348
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2346

def private_key_name
  @private_key_name
end

#private_key_version_nameString

The resource name for the private key secret version. Corresponds to the JSON property privateKeyVersionName

Returns:

  • (String)


2351
2352
2353
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2351

def private_key_version_name
  @private_key_version_name
end

#webhook_secret_nameString

The resource name for the webhook secret in Secret Manager. Corresponds to the JSON property webhookSecretName

Returns:

  • (String)


2356
2357
2358
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2356

def webhook_secret_name
  @webhook_secret_name
end

#webhook_secret_version_nameString

The resource name for the webhook secret secret version in Secret Manager. Corresponds to the JSON property webhookSecretVersionName

Returns:

  • (String)


2361
2362
2363
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2361

def webhook_secret_version_name
  @webhook_secret_version_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2368

def update!(**args)
  @oauth_client_id_name = args[:oauth_client_id_name] if args.key?(:oauth_client_id_name)
  @oauth_client_id_version_name = args[:oauth_client_id_version_name] if args.key?(:oauth_client_id_version_name)
  @oauth_secret_name = args[:oauth_secret_name] if args.key?(:oauth_secret_name)
  @oauth_secret_version_name = args[:oauth_secret_version_name] if args.key?(:oauth_secret_version_name)
  @private_key_name = args[:private_key_name] if args.key?(:private_key_name)
  @private_key_version_name = args[:private_key_version_name] if args.key?(:private_key_version_name)
  @webhook_secret_name = args[:webhook_secret_name] if args.key?(:webhook_secret_name)
  @webhook_secret_version_name = args[:webhook_secret_version_name] if args.key?(:webhook_secret_version_name)
end