Class: Google::Apis::CloudbuildV1::GitLabConnectedRepository

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

GitLabConnectedRepository represents a GitLab connected repository request response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitLabConnectedRepository

Returns a new instance of GitLabConnectedRepository.



2519
2520
2521
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2519

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parentString

The name of the GitLabConfig that added connected repository. Format: projects/project/locations/location/gitLabConfigs/config` Corresponds to the JSON propertyparent`

Returns:

  • (String)


2501
2502
2503
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2501

def parent
  @parent
end

#repoGoogle::Apis::CloudbuildV1::GitLabRepositoryId

GitLabRepositoryId identifies a specific repository hosted on GitLab.com or GitLabEnterprise Corresponds to the JSON property repo



2507
2508
2509
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2507

def repo
  @repo
end

#statusGoogle::Apis::CloudbuildV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



2517
2518
2519
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2517

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2524
2525
2526
2527
2528
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2524

def update!(**args)
  @parent = args[:parent] if args.key?(:parent)
  @repo = args[:repo] if args.key?(:repo)
  @status = args[:status] if args.key?(:status)
end