Class: Google::Apis::CloudbuildV1::GitLabSecrets

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

GitLabSecrets represents the secrets in Secret Manager for a GitLab integration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitLabSecrets

Returns a new instance of GitLabSecrets.



2819
2820
2821
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_access_token_versionString

Required. The resource name for the api access token’s secret version Corresponds to the JSON property apiAccessTokenVersion

Returns:

  • (String)


2799
2800
2801
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2799

def api_access_token_version
  @api_access_token_version
end

#api_key_versionString

Required. Immutable. API Key that will be attached to webhook requests from GitLab to Cloud Build. Corresponds to the JSON property apiKeyVersion

Returns:

  • (String)


2805
2806
2807
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2805

def api_key_version
  @api_key_version
end

#read_access_token_versionString

Required. The resource name for the read access token’s secret version Corresponds to the JSON property readAccessTokenVersion

Returns:

  • (String)


2810
2811
2812
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2810

def read_access_token_version
  @read_access_token_version
end

#webhook_secret_versionString

Required. Immutable. The resource name for the webhook secret’s secret version. Once this field has been set, it cannot be changed. If you need to change it, please create another GitLabConfig. Corresponds to the JSON property webhookSecretVersion

Returns:

  • (String)


2817
2818
2819
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2817

def webhook_secret_version
  @webhook_secret_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2824
2825
2826
2827
2828
2829
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2824

def update!(**args)
  @api_access_token_version = args[:api_access_token_version] if args.key?(:api_access_token_version)
  @api_key_version = args[:api_key_version] if args.key?(:api_key_version)
  @read_access_token_version = args[:read_access_token_version] if args.key?(:read_access_token_version)
  @webhook_secret_version = args[:webhook_secret_version] if args.key?(:webhook_secret_version)
end