Class: Google::Apis::CloudbuildV1::GitSourceDependency

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

Represents a git repository as a build dependency.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitSourceDependency

Returns a new instance of GitSourceDependency.



2847
2848
2849
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2847

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#depthFixnum

Optional. How much history should be fetched for the build (default 1, -1 for all history). Corresponds to the JSON property depth

Returns:

  • (Fixnum)


2824
2825
2826
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2824

def depth
  @depth
end

#dest_pathString

Required. Where should the files be placed on the worker. Corresponds to the JSON property destPath

Returns:

  • (String)


2829
2830
2831
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2829

def dest_path
  @dest_path
end

#recurse_submodulesBoolean Also known as: recurse_submodules?

Optional. True if submodules should be fetched too (default false). Corresponds to the JSON property recurseSubmodules

Returns:

  • (Boolean)


2834
2835
2836
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2834

def recurse_submodules
  @recurse_submodules
end

#repositoryGoogle::Apis::CloudbuildV1::GitSourceRepository

A repository for a git source. Corresponds to the JSON property repository



2840
2841
2842
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2840

def repository
  @repository
end

#revisionString

Required. The revision that we will fetch the repo at. Corresponds to the JSON property revision

Returns:

  • (String)


2845
2846
2847
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2845

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2852
2853
2854
2855
2856
2857
2858
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 2852

def update!(**args)
  @depth = args[:depth] if args.key?(:depth)
  @dest_path = args[:dest_path] if args.key?(:dest_path)
  @recurse_submodules = args[:recurse_submodules] if args.key?(:recurse_submodules)
  @repository = args[:repository] if args.key?(:repository)
  @revision = args[:revision] if args.key?(:revision)
end