Class: Google::Apis::CloudbuildV1::GoModule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

Go module to upload to Artifact Registry upon successful completion of all build steps. A module refers to all dependencies in a go.mod file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoModule

Returns a new instance of GoModule.



3041
3042
3043
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3041

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#module_pathString

Optional. The Go module's "module path". e.g. example.com/foo/v2 Corresponds to the JSON property modulePath

Returns:

  • (String)


3006
3007
3008
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3006

def module_path
  @module_path
end

#module_versionString

Optional. The Go module's semantic version in the form vX.Y.Z. e.g. v0.1.1 Pre- release identifiers can also be added by appending a dash and dot separated ASCII alphanumeric characters and hyphens. e.g. v0.2.3-alpha.x.12m.5 Corresponds to the JSON property moduleVersion

Returns:

  • (String)


3013
3014
3015
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3013

def module_version
  @module_version
end

#repository_locationString

Optional. Location of the Artifact Registry repository. i.e. us-east1 Defaults to the build’s location. Corresponds to the JSON property repositoryLocation

Returns:

  • (String)


3019
3020
3021
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3019

def repository_location
  @repository_location
end

#repository_nameString

Optional. Artifact Registry repository name. Specified Go modules will be zipped and uploaded to Artifact Registry with this location as a prefix. e.g. my-go-repo Corresponds to the JSON property repositoryName

Returns:

  • (String)


3026
3027
3028
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3026

def repository_name
  @repository_name
end

#repository_project_idString

Optional. Project ID of the Artifact Registry repository. Defaults to the build project. Corresponds to the JSON property repositoryProjectId

Returns:

  • (String)


3032
3033
3034
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3032

def repository_project_id
  @repository_project_id
end

#source_pathString

Optional. Source path of the go.mod file in the build's workspace. If not specified, this will default to the current directory. e.g. ~/code/go/ mypackage Corresponds to the JSON property sourcePath

Returns:

  • (String)


3039
3040
3041
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3039

def source_path
  @source_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3046
3047
3048
3049
3050
3051
3052
3053
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3046

def update!(**args)
  @module_path = args[:module_path] if args.key?(:module_path)
  @module_version = args[:module_version] if args.key?(:module_version)
  @repository_location = args[:repository_location] if args.key?(:repository_location)
  @repository_name = args[:repository_name] if args.key?(:repository_name)
  @repository_project_id = args[:repository_project_id] if args.key?(:repository_project_id)
  @source_path = args[:source_path] if args.key?(:source_path)
end