Class: Google::Apis::CloudbuildV1::Oci
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::Oci
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
OCI image to upload to Artifact Registry upon successful completion of all build steps.
Instance Attribute Summary collapse
-
#file ⇒ String
Required.
-
#registry_path ⇒ String
Required.
-
#tags ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Oci
constructor
A new instance of Oci.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Oci
Returns a new instance of Oci.
3534 3535 3536 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3534 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file ⇒ String
Required. Path on the local file system where to find the container to upload.
e.g. /workspace/my-image.tar
Corresponds to the JSON property file
3521 3522 3523 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3521 def file @file end |
#registry_path ⇒ String
Required. Registry path to upload the container to. e.g. us-east1-docker.pkg.
dev/my-project/my-repo/my-image
Corresponds to the JSON property registryPath
3527 3528 3529 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3527 def registry_path @registry_path end |
#tags ⇒ Array<String>
Optional. Tags to apply to the uploaded image. e.g. latest, 1.0.0
Corresponds to the JSON property tags
3532 3533 3534 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3532 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3539 3540 3541 3542 3543 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3539 def update!(**args) @file = args[:file] if args.key?(:file) @registry_path = args[:registry_path] if args.key?(:registry_path) @tags = args[:tags] if args.key?(:tags) end |