Class: Google::Apis::CloudbuildV1::PrivatePoolV1Config

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

Configuration for a V1 PrivatePool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrivatePoolV1Config

Returns a new instance of PrivatePoolV1Config.



3564
3565
3566
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3564

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#network_configGoogle::Apis::CloudbuildV1::NetworkConfig

Defines the network configuration for the pool. Corresponds to the JSON property networkConfig



3552
3553
3554
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3552

def network_config
  @network_config
end

#private_service_connectGoogle::Apis::CloudbuildV1::PrivateServiceConnect

Defines the Private Service Connect network configuration for the pool. Corresponds to the JSON property privateServiceConnect



3557
3558
3559
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3557

def private_service_connect
  @private_service_connect
end

#worker_configGoogle::Apis::CloudbuildV1::WorkerConfig

Defines the configuration to be used for creating workers in the pool. Corresponds to the JSON property workerConfig



3562
3563
3564
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3562

def worker_config
  @worker_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3569
3570
3571
3572
3573
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3569

def update!(**args)
  @network_config = args[:network_config] if args.key?(:network_config)
  @private_service_connect = args[:private_service_connect] if args.key?(:private_service_connect)
  @worker_config = args[:worker_config] if args.key?(:worker_config)
end