Class: Google::Apis::CloudbuildV1::PrivateServiceConnect
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::PrivateServiceConnect
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
Defines the Private Service Connect network configuration for the pool.
Instance Attribute Summary collapse
-
#network_attachment ⇒ String
Required.
-
#public_ip_address_disabled ⇒ Boolean
(also: #public_ip_address_disabled?)
Required.
-
#route_all_traffic ⇒ Boolean
(also: #route_all_traffic?)
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PrivateServiceConnect
constructor
A new instance of PrivateServiceConnect.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PrivateServiceConnect
Returns a new instance of PrivateServiceConnect.
3756 3757 3758 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3756 def initialize(**args) update!(**args) end |
Instance Attribute Details
#network_attachment ⇒ String
Required. Immutable. The network attachment that the worker network interface
is peered to. Must be in the format projects/project/regions/region/
networkAttachments/networkAttachment`. The region of network attachment must
be the same as the worker pool. See [Network Attachments](https://cloud.google.
com/vpc/docs/about-network-attachments)
Corresponds to the JSON propertynetworkAttachment`
3732 3733 3734 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3732 def @network_attachment end |
#public_ip_address_disabled ⇒ Boolean Also known as: public_ip_address_disabled?
Required. Immutable. Disable public IP on the primary network interface. If
true, workers are created without any public address, which prevents network
egress to public IPs unless a network proxy is configured. If false, workers
are created with a public address which allows for public internet egress. The
public address only applies to traffic through the primary network interface.
If route_all_traffic is set to true, all traffic will go through the non-
primary network interface, this boolean has no effect.
Corresponds to the JSON property publicIpAddressDisabled
3743 3744 3745 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3743 def public_ip_address_disabled @public_ip_address_disabled end |
#route_all_traffic ⇒ Boolean Also known as: route_all_traffic?
Immutable. Route all traffic through PSC interface. Enable this if you want
full control of traffic in the private pool. Configure Cloud NAT for the
subnet of network attachment if you need to access public Internet. If false,
Only route RFC 1918 (10.0.0.0/8, 172.16.0.0/12, and 192.168.0.0/16) and RFC
6598 (100.64.0.0/10) through PSC interface.
Corresponds to the JSON property routeAllTraffic
3753 3754 3755 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3753 def route_all_traffic @route_all_traffic end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3761 3762 3763 3764 3765 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3761 def update!(**args) @network_attachment = args[:network_attachment] if args.key?(:network_attachment) @public_ip_address_disabled = args[:public_ip_address_disabled] if args.key?(:public_ip_address_disabled) @route_all_traffic = args[:route_all_traffic] if args.key?(:route_all_traffic) end |