Class: Google::Apis::CloudbuildV1::Results

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

Artifacts created by the build pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Results

Returns a new instance of Results.



4027
4028
4029
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4027

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_manifestString

Path to the artifact manifest for non-container artifacts uploaded to Cloud Storage. Only populated when artifacts are uploaded to Cloud Storage. Corresponds to the JSON property artifactManifest

Returns:

  • (String)


3974
3975
3976
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3974

def artifact_manifest
  @artifact_manifest
end

#artifact_timingGoogle::Apis::CloudbuildV1::TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property artifactTiming



3979
3980
3981
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3979

def artifact_timing
  @artifact_timing
end

#build_step_imagesArray<String>

List of build step digests, in the order corresponding to build step indices. Corresponds to the JSON property buildStepImages

Returns:

  • (Array<String>)


3984
3985
3986
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3984

def build_step_images
  @build_step_images
end

#build_step_outputsArray<String>

List of build step outputs, produced by builder images, in the order corresponding to build step indices. Cloud Builders can produce this output by writing to $ BUILDER_OUTPUT/output. Only the first 50KB of data is stored. Note that the $ BUILDER_OUTPUT variable is read-only and can't be substituted. Corresponds to the JSON property buildStepOutputs

Returns:

  • (Array<String>)


3993
3994
3995
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3993

def build_step_outputs
  @build_step_outputs
end

#go_modulesArray<Google::Apis::CloudbuildV1::UploadedGoModule>

Optional. Go module artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property goModules



3999
4000
4001
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 3999

def go_modules
  @go_modules
end

#imagesArray<Google::Apis::CloudbuildV1::BuiltImage>

Container images that were built as a part of the build. Corresponds to the JSON property images



4004
4005
4006
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4004

def images
  @images
end

#maven_artifactsArray<Google::Apis::CloudbuildV1::UploadedMavenArtifact>

Maven artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property mavenArtifacts



4009
4010
4011
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4009

def maven_artifacts
  @maven_artifacts
end

#npm_packagesArray<Google::Apis::CloudbuildV1::UploadedNpmPackage>

Npm packages uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property npmPackages



4014
4015
4016
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4014

def npm_packages
  @npm_packages
end

#num_artifactsFixnum

Number of non-container artifacts uploaded to Cloud Storage. Only populated when artifacts are uploaded to Cloud Storage. Corresponds to the JSON property numArtifacts

Returns:

  • (Fixnum)


4020
4021
4022
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4020

def num_artifacts
  @num_artifacts
end

#python_packagesArray<Google::Apis::CloudbuildV1::UploadedPythonPackage>

Python artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property pythonPackages



4025
4026
4027
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4025

def python_packages
  @python_packages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4032
4033
4034
4035
4036
4037
4038
4039
4040
4041
4042
4043
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4032

def update!(**args)
  @artifact_manifest = args[:artifact_manifest] if args.key?(:artifact_manifest)
  @artifact_timing = args[:artifact_timing] if args.key?(:artifact_timing)
  @build_step_images = args[:build_step_images] if args.key?(:build_step_images)
  @build_step_outputs = args[:build_step_outputs] if args.key?(:build_step_outputs)
  @go_modules = args[:go_modules] if args.key?(:go_modules)
  @images = args[:images] if args.key?(:images)
  @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts)
  @npm_packages = args[:npm_packages] if args.key?(:npm_packages)
  @num_artifacts = args[:num_artifacts] if args.key?(:num_artifacts)
  @python_packages = args[:python_packages] if args.key?(:python_packages)
end