Class: Google::Apis::CloudbuildV1::SourceProvenance
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::SourceProvenance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
Provenance of the source. Ways to find the original source, or verify that some source was used for this build.
Instance Attribute Summary collapse
-
#file_hashes ⇒ Hash<String,Google::Apis::CloudbuildV1::FileHashes>
Output only.
-
#resolved_connected_repository ⇒ Google::Apis::CloudbuildV1::ConnectedRepository
Location of the source in a 2nd-gen Google Cloud Build repository resource.
-
#resolved_git_source ⇒ Google::Apis::CloudbuildV1::GitSource
Location of the source in any accessible Git repository.
-
#resolved_repo_source ⇒ Google::Apis::CloudbuildV1::RepoSource
Location of the source in a Google Cloud Source Repository.
-
#resolved_storage_source ⇒ Google::Apis::CloudbuildV1::StorageSource
Location of the source in an archive file in Cloud Storage.
-
#resolved_storage_source_manifest ⇒ Google::Apis::CloudbuildV1::StorageSourceManifest
Location of the source manifest in Cloud Storage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SourceProvenance
constructor
A new instance of SourceProvenance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SourceProvenance
Returns a new instance of SourceProvenance.
4466 4467 4468 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4466 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_hashes ⇒ Hash<String,Google::Apis::CloudbuildV1::FileHashes>
Output only. Hash(es) of the build source, which can be used to verify that
the original source integrity was maintained in the build. Note that
FileHashes will only be populated if BuildOptions has requested a
SourceProvenanceHash. The keys to this map are file paths used as build
source and the values contain the hash values for those files. If the build
source came in a single package such as a gzipped tarfile (.tar.gz), the
FileHash will be for the single path to that file.
Corresponds to the JSON property fileHashes
4437 4438 4439 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4437 def file_hashes @file_hashes end |
#resolved_connected_repository ⇒ Google::Apis::CloudbuildV1::ConnectedRepository
Location of the source in a 2nd-gen Google Cloud Build repository resource.
Corresponds to the JSON property resolvedConnectedRepository
4442 4443 4444 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4442 def resolved_connected_repository @resolved_connected_repository end |
#resolved_git_source ⇒ Google::Apis::CloudbuildV1::GitSource
Location of the source in any accessible Git repository.
Corresponds to the JSON property resolvedGitSource
4447 4448 4449 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4447 def resolved_git_source @resolved_git_source end |
#resolved_repo_source ⇒ Google::Apis::CloudbuildV1::RepoSource
Location of the source in a Google Cloud Source Repository.
Corresponds to the JSON property resolvedRepoSource
4452 4453 4454 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4452 def resolved_repo_source @resolved_repo_source end |
#resolved_storage_source ⇒ Google::Apis::CloudbuildV1::StorageSource
Location of the source in an archive file in Cloud Storage.
Corresponds to the JSON property resolvedStorageSource
4457 4458 4459 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4457 def resolved_storage_source @resolved_storage_source end |
#resolved_storage_source_manifest ⇒ Google::Apis::CloudbuildV1::StorageSourceManifest
Location of the source manifest in Cloud Storage. This feature is in Preview;
see description here.
Corresponds to the JSON property resolvedStorageSourceManifest
4464 4465 4466 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4464 def resolved_storage_source_manifest @resolved_storage_source_manifest end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4471 4472 4473 4474 4475 4476 4477 4478 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4471 def update!(**args) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @resolved_connected_repository = args[:resolved_connected_repository] if args.key?(:resolved_connected_repository) @resolved_git_source = args[:resolved_git_source] if args.key?(:resolved_git_source) @resolved_repo_source = args[:resolved_repo_source] if args.key?(:resolved_repo_source) @resolved_storage_source = args[:resolved_storage_source] if args.key?(:resolved_storage_source) @resolved_storage_source_manifest = args[:resolved_storage_source_manifest] if args.key?(:resolved_storage_source_manifest) end |