Class: Google::Apis::CloudbuildV1::SourceProvenance
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::SourceProvenance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
Provenance of the source. Ways to find the original source, or verify that some source was used for this build.
Instance Attribute Summary collapse
-
#file_hashes ⇒ Hash<String,Google::Apis::CloudbuildV1::FileHashes>
Output only.
-
#resolved_connected_repository ⇒ Google::Apis::CloudbuildV1::ConnectedRepository
Location of the source in a 2nd-gen Google Cloud Build repository resource.
-
#resolved_git_source ⇒ Google::Apis::CloudbuildV1::GitSource
Location of the source in any accessible Git repository.
-
#resolved_repo_source ⇒ Google::Apis::CloudbuildV1::RepoSource
Location of the source in a Google Cloud Source Repository.
-
#resolved_storage_source ⇒ Google::Apis::CloudbuildV1::StorageSource
Location of the source in an archive file in Cloud Storage.
-
#resolved_storage_source_manifest ⇒ Google::Apis::CloudbuildV1::StorageSourceManifest
Location of the source manifest in Cloud Storage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SourceProvenance
constructor
A new instance of SourceProvenance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SourceProvenance
Returns a new instance of SourceProvenance.
4308 4309 4310 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4308 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_hashes ⇒ Hash<String,Google::Apis::CloudbuildV1::FileHashes>
Output only. Hash(es) of the build source, which can be used to verify that
the original source integrity was maintained in the build. Note that
FileHashes will only be populated if BuildOptions has requested a
SourceProvenanceHash. The keys to this map are file paths used as build
source and the values contain the hash values for those files. If the build
source came in a single package such as a gzipped tarfile (.tar.gz), the
FileHash will be for the single path to that file.
Corresponds to the JSON property fileHashes
4279 4280 4281 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4279 def file_hashes @file_hashes end |
#resolved_connected_repository ⇒ Google::Apis::CloudbuildV1::ConnectedRepository
Location of the source in a 2nd-gen Google Cloud Build repository resource.
Corresponds to the JSON property resolvedConnectedRepository
4284 4285 4286 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4284 def resolved_connected_repository @resolved_connected_repository end |
#resolved_git_source ⇒ Google::Apis::CloudbuildV1::GitSource
Location of the source in any accessible Git repository.
Corresponds to the JSON property resolvedGitSource
4289 4290 4291 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4289 def resolved_git_source @resolved_git_source end |
#resolved_repo_source ⇒ Google::Apis::CloudbuildV1::RepoSource
Location of the source in a Google Cloud Source Repository.
Corresponds to the JSON property resolvedRepoSource
4294 4295 4296 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4294 def resolved_repo_source @resolved_repo_source end |
#resolved_storage_source ⇒ Google::Apis::CloudbuildV1::StorageSource
Location of the source in an archive file in Cloud Storage.
Corresponds to the JSON property resolvedStorageSource
4299 4300 4301 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4299 def resolved_storage_source @resolved_storage_source end |
#resolved_storage_source_manifest ⇒ Google::Apis::CloudbuildV1::StorageSourceManifest
Location of the source manifest in Cloud Storage. This feature is in Preview;
see description here.
Corresponds to the JSON property resolvedStorageSourceManifest
4306 4307 4308 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4306 def resolved_storage_source_manifest @resolved_storage_source_manifest end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4313 4314 4315 4316 4317 4318 4319 4320 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4313 def update!(**args) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @resolved_connected_repository = args[:resolved_connected_repository] if args.key?(:resolved_connected_repository) @resolved_git_source = args[:resolved_git_source] if args.key?(:resolved_git_source) @resolved_repo_source = args[:resolved_repo_source] if args.key?(:resolved_repo_source) @resolved_storage_source = args[:resolved_storage_source] if args.key?(:resolved_storage_source) @resolved_storage_source_manifest = args[:resolved_storage_source_manifest] if args.key?(:resolved_storage_source_manifest) end |