Class: Google::Apis::CloudbuildV1::UploadedGenericArtifact
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::UploadedGenericArtifact
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
A generic artifact uploaded to Artifact Registry using the GenericArtifact directive.
Instance Attribute Summary collapse
-
#artifact_fingerprint ⇒ Google::Apis::CloudbuildV1::FileHashes
Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.
-
#artifact_registry_package ⇒ String
Output only.
-
#file_hashes ⇒ Hash<String,Google::Apis::CloudbuildV1::FileHashes>
Output only.
-
#push_timing ⇒ Google::Apis::CloudbuildV1::TimeSpan
Start and end times for a build execution phase.
-
#uri ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UploadedGenericArtifact
constructor
A new instance of UploadedGenericArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UploadedGenericArtifact
Returns a new instance of UploadedGenericArtifact.
4813 4814 4815 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4813 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_fingerprint ⇒ Google::Apis::CloudbuildV1::FileHashes
Container message for hashes of byte content of files, used in
SourceProvenance messages to verify integrity of source input to the build.
Corresponds to the JSON property artifactFingerprint
4790 4791 4792 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4790 def artifact_fingerprint @artifact_fingerprint end |
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
4795 4796 4797 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4795 def artifact_registry_package @artifact_registry_package end |
#file_hashes ⇒ Hash<String,Google::Apis::CloudbuildV1::FileHashes>
Output only. The file hashes that make up the generic artifact.
Corresponds to the JSON property fileHashes
4800 4801 4802 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4800 def file_hashes @file_hashes end |
#push_timing ⇒ Google::Apis::CloudbuildV1::TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
4805 4806 4807 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4805 def push_timing @push_timing end |
#uri ⇒ String
Output only. URI of the uploaded artifact. Ex: projects/p1/locations/us/
repositories/r1/packages/p1/versions/v1
Corresponds to the JSON property uri
4811 4812 4813 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4811 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4818 4819 4820 4821 4822 4823 4824 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4818 def update!(**args) @artifact_fingerprint = args[:artifact_fingerprint] if args.key?(:artifact_fingerprint) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @push_timing = args[:push_timing] if args.key?(:push_timing) @uri = args[:uri] if args.key?(:uri) end |