Class: Google::Apis::CloudbuildV1::UploadedGoModule
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::UploadedGoModule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
A Go module artifact uploaded to Artifact Registry using the GoModule directive.
Instance Attribute Summary collapse
-
#artifact_registry_package ⇒ String
Output only.
-
#file_hashes ⇒ Google::Apis::CloudbuildV1::FileHashes
Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.
-
#push_timing ⇒ Google::Apis::CloudbuildV1::TimeSpan
Start and end times for a build execution phase.
-
#uri ⇒ String
URI of the uploaded artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UploadedGoModule
constructor
A new instance of UploadedGoModule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UploadedGoModule
Returns a new instance of UploadedGoModule.
4853 4854 4855 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4853 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
4835 4836 4837 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4835 def artifact_registry_package @artifact_registry_package end |
#file_hashes ⇒ Google::Apis::CloudbuildV1::FileHashes
Container message for hashes of byte content of files, used in
SourceProvenance messages to verify integrity of source input to the build.
Corresponds to the JSON property fileHashes
4841 4842 4843 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4841 def file_hashes @file_hashes end |
#push_timing ⇒ Google::Apis::CloudbuildV1::TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
4846 4847 4848 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4846 def push_timing @push_timing end |
#uri ⇒ String
URI of the uploaded artifact.
Corresponds to the JSON property uri
4851 4852 4853 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4851 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4858 4859 4860 4861 4862 4863 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4858 def update!(**args) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @push_timing = args[:push_timing] if args.key?(:push_timing) @uri = args[:uri] if args.key?(:uri) end |