Class: Google::Apis::CloudbuildV1::UploadedGoModule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

A Go module artifact uploaded to Artifact Registry using the GoModule directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UploadedGoModule

Returns a new instance of UploadedGoModule.



4618
4619
4620
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4618

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


4600
4601
4602
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4600

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::CloudbuildV1::FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



4606
4607
4608
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4606

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::CloudbuildV1::TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



4611
4612
4613
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4611

def push_timing
  @push_timing
end

#uriString

URI of the uploaded artifact. Corresponds to the JSON property uri

Returns:

  • (String)


4616
4617
4618
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4616

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4623
4624
4625
4626
4627
4628
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4623

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end