Class: Google::Apis::CloudbuildV1::UploadedMavenArtifact
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::UploadedMavenArtifact
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
A Maven artifact uploaded using the MavenArtifact directive.
Instance Attribute Summary collapse
-
#artifact_registry_package ⇒ String
Output only.
-
#file_hashes ⇒ Google::Apis::CloudbuildV1::FileHashes
Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.
-
#push_timing ⇒ Google::Apis::CloudbuildV1::TimeSpan
Start and end times for a build execution phase.
-
#uri ⇒ String
URI of the uploaded artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UploadedMavenArtifact
constructor
A new instance of UploadedMavenArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UploadedMavenArtifact
Returns a new instance of UploadedMavenArtifact.
4891 4892 4893 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4891 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
4873 4874 4875 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4873 def artifact_registry_package @artifact_registry_package end |
#file_hashes ⇒ Google::Apis::CloudbuildV1::FileHashes
Container message for hashes of byte content of files, used in
SourceProvenance messages to verify integrity of source input to the build.
Corresponds to the JSON property fileHashes
4879 4880 4881 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4879 def file_hashes @file_hashes end |
#push_timing ⇒ Google::Apis::CloudbuildV1::TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
4884 4885 4886 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4884 def push_timing @push_timing end |
#uri ⇒ String
URI of the uploaded artifact.
Corresponds to the JSON property uri
4889 4890 4891 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4889 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4896 4897 4898 4899 4900 4901 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4896 def update!(**args) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @push_timing = args[:push_timing] if args.key?(:push_timing) @uri = args[:uri] if args.key?(:uri) end |