Class: Google::Apis::CloudbuildV1::UploadedNpmPackage
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::UploadedNpmPackage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
An npm package uploaded to Artifact Registry using the NpmPackage directive.
Instance Attribute Summary collapse
-
#artifact_registry_package ⇒ String
Output only.
-
#file_hashes ⇒ Google::Apis::CloudbuildV1::FileHashes
Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.
-
#push_timing ⇒ Google::Apis::CloudbuildV1::TimeSpan
Start and end times for a build execution phase.
-
#uri ⇒ String
URI of the uploaded npm package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UploadedNpmPackage
constructor
A new instance of UploadedNpmPackage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UploadedNpmPackage
Returns a new instance of UploadedNpmPackage.
4929 4930 4931 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4929 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
4911 4912 4913 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4911 def artifact_registry_package @artifact_registry_package end |
#file_hashes ⇒ Google::Apis::CloudbuildV1::FileHashes
Container message for hashes of byte content of files, used in
SourceProvenance messages to verify integrity of source input to the build.
Corresponds to the JSON property fileHashes
4917 4918 4919 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4917 def file_hashes @file_hashes end |
#push_timing ⇒ Google::Apis::CloudbuildV1::TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
4922 4923 4924 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4922 def push_timing @push_timing end |
#uri ⇒ String
URI of the uploaded npm package.
Corresponds to the JSON property uri
4927 4928 4929 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4927 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4934 4935 4936 4937 4938 4939 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4934 def update!(**args) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @push_timing = args[:push_timing] if args.key?(:push_timing) @uri = args[:uri] if args.key?(:uri) end |