Class: Google::Apis::CloudbuildV1::UploadedNpmPackage
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::UploadedNpmPackage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
An npm package uploaded to Artifact Registry using the NpmPackage directive.
Instance Attribute Summary collapse
-
#artifact_registry_package ⇒ String
Output only.
-
#file_hashes ⇒ Google::Apis::CloudbuildV1::FileHashes
Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.
-
#push_timing ⇒ Google::Apis::CloudbuildV1::TimeSpan
Start and end times for a build execution phase.
-
#uri ⇒ String
URI of the uploaded npm package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UploadedNpmPackage
constructor
A new instance of UploadedNpmPackage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UploadedNpmPackage
Returns a new instance of UploadedNpmPackage.
4694 4695 4696 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4694 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
4676 4677 4678 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4676 def artifact_registry_package @artifact_registry_package end |
#file_hashes ⇒ Google::Apis::CloudbuildV1::FileHashes
Container message for hashes of byte content of files, used in
SourceProvenance messages to verify integrity of source input to the build.
Corresponds to the JSON property fileHashes
4682 4683 4684 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4682 def file_hashes @file_hashes end |
#push_timing ⇒ Google::Apis::CloudbuildV1::TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
4687 4688 4689 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4687 def push_timing @push_timing end |
#uri ⇒ String
URI of the uploaded npm package.
Corresponds to the JSON property uri
4692 4693 4694 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4692 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4699 4700 4701 4702 4703 4704 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4699 def update!(**args) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @push_timing = args[:push_timing] if args.key?(:push_timing) @uri = args[:uri] if args.key?(:uri) end |