Class: Google::Apis::CloudbuildV1::UploadedPythonPackage
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::UploadedPythonPackage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
Artifact uploaded using the PythonPackage directive.
Instance Attribute Summary collapse
-
#artifact_registry_package ⇒ String
Output only.
-
#file_hashes ⇒ Google::Apis::CloudbuildV1::FileHashes
Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.
-
#push_timing ⇒ Google::Apis::CloudbuildV1::TimeSpan
Start and end times for a build execution phase.
-
#uri ⇒ String
URI of the uploaded artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UploadedPythonPackage
constructor
A new instance of UploadedPythonPackage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UploadedPythonPackage
Returns a new instance of UploadedPythonPackage.
4988 4989 4990 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4988 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
4970 4971 4972 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4970 def artifact_registry_package @artifact_registry_package end |
#file_hashes ⇒ Google::Apis::CloudbuildV1::FileHashes
Container message for hashes of byte content of files, used in
SourceProvenance messages to verify integrity of source input to the build.
Corresponds to the JSON property fileHashes
4976 4977 4978 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4976 def file_hashes @file_hashes end |
#push_timing ⇒ Google::Apis::CloudbuildV1::TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
4981 4982 4983 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4981 def push_timing @push_timing end |
#uri ⇒ String
URI of the uploaded artifact.
Corresponds to the JSON property uri
4986 4987 4988 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4986 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4993 4994 4995 4996 4997 4998 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4993 def update!(**args) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @push_timing = args[:push_timing] if args.key?(:push_timing) @uri = args[:uri] if args.key?(:uri) end |