Class: Google::Apis::CloudbuildV1::UploadedPythonPackage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

Artifact uploaded using the PythonPackage directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UploadedPythonPackage

Returns a new instance of UploadedPythonPackage.



4967
4968
4969
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4967

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


4949
4950
4951
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4949

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::CloudbuildV1::FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



4955
4956
4957
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4955

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::CloudbuildV1::TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



4960
4961
4962
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4960

def push_timing
  @push_timing
end

#uriString

URI of the uploaded artifact. Corresponds to the JSON property uri

Returns:

  • (String)


4965
4966
4967
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4965

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4972
4973
4974
4975
4976
4977
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4972

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end