Class: Google::Apis::CloudbuildV1::UploadedPythonPackage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb

Overview

Artifact uploaded using the PythonPackage directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UploadedPythonPackage

Returns a new instance of UploadedPythonPackage.



4732
4733
4734
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4732

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


4714
4715
4716
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4714

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::CloudbuildV1::FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



4720
4721
4722
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4720

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::CloudbuildV1::TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



4725
4726
4727
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4725

def push_timing
  @push_timing
end

#uriString

URI of the uploaded artifact. Corresponds to the JSON property uri

Returns:

  • (String)


4730
4731
4732
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4730

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4737
4738
4739
4740
4741
4742
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4737

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end