Class: Google::Apis::CloudbuildV1::WorkerConfig
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV1::WorkerConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v1/classes.rb,
lib/google/apis/cloudbuild_v1/representations.rb,
lib/google/apis/cloudbuild_v1/representations.rb
Overview
Defines the configuration to be used for creating workers in the pool.
Instance Attribute Summary collapse
-
#disk_size_gb ⇒ Fixnum
Size of the disk attached to the worker, in GB.
-
#enable_nested_virtualization ⇒ Boolean
(also: #enable_nested_virtualization?)
Optional.
-
#machine_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkerConfig
constructor
A new instance of WorkerConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkerConfig
Returns a new instance of WorkerConfig.
4853 4854 4855 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4853 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disk_size_gb ⇒ Fixnum
Size of the disk attached to the worker, in GB. See Worker pool config file. Specify a value of up to 4000. If 0 is specified, Cloud Build will
use a standard disk size.
Corresponds to the JSON property diskSizeGb
4837 4838 4839 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4837 def disk_size_gb @disk_size_gb end |
#enable_nested_virtualization ⇒ Boolean Also known as: enable_nested_virtualization?
Optional. Enable nested virtualization on the worker, if supported by the
machine type. By default, nested virtualization is disabled.
Corresponds to the JSON property enableNestedVirtualization
4843 4844 4845 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4843 def enable_nested_virtualization @enable_nested_virtualization end |
#machine_type ⇒ String
Optional. Machine type of a worker, such as e2-medium. See Worker pool
config file. If left blank, Cloud Build will use a sensible default.
Corresponds to the JSON property machineType
4851 4852 4853 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4851 def machine_type @machine_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4858 4859 4860 4861 4862 |
# File 'lib/google/apis/cloudbuild_v1/classes.rb', line 4858 def update!(**args) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @enable_nested_virtualization = args[:enable_nested_virtualization] if args.key?(:enable_nested_virtualization) @machine_type = args[:machine_type] if args.key?(:machine_type) end |